# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nidcpower.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nidevice_pb2 as nidevice__pb2
from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fnidcpower.proto\x12\x0enidcpower_grpc\x1a\x0enidevice.proto\x1a\rsession.proto\"\x92\x04\n\x10NILCRMeasurement\x12\x0b\n\x03vdc\x18\x01 \x01(\x01\x12\x0b\n\x03idc\x18\x02 \x01(\x01\x12\x1a\n\x12stimulus_frequency\x18\x03 \x01(\x01\x12\x32\n\nac_voltage\x18\x04 \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x32\n\nac_current\x18\x05 \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12)\n\x01z\x18\x06 \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x13\n\x0bz_magnitude\x18\x07 \x01(\x01\x12\x0f\n\x07z_phase\x18\x08 \x01(\x01\x12)\n\x01y\x18\t \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x13\n\x0by_magnitude\x18\n \x01(\x01\x12\x0f\n\x07y_phase\x18\x0b \x01(\x01\x12\n\n\x02ls\x18\x0c \x01(\x01\x12\n\n\x02\x63s\x18\r \x01(\x01\x12\n\n\x02rs\x18\x0e \x01(\x01\x12\n\n\x02lp\x18\x0f \x01(\x01\x12\n\n\x02\x63p\x18\x10 \x01(\x01\x12\n\n\x02rp\x18\x11 \x01(\x01\x12\t\n\x01\x64\x18\x12 \x01(\x01\x12\t\n\x01q\x18\x13 \x01(\x01\x12\x18\n\x10measurement_mode\x18\x14 \x01(\r\x12\x18\n\x10\x64\x63_in_compliance\x18\x15 \x01(\x08\x12\x18\n\x10\x61\x63_in_compliance\x18\x16 \x01(\x08\x12\x12\n\nunbalanced\x18\x17 \x01(\x08\"\x82\x01\n\x19NILCRLoadCompensationSpot\x12\x11\n\tfrequency\x18\x01 \x01(\x01\x12\x1c\n\x14reference_value_type\x18\x02 \x01(\x11\x12\x19\n\x11reference_value_a\x18\x03 \x01(\x01\x12\x19\n\x11reference_value_b\x18\x04 \x01(\x01\"\xd3\x01\n\x1dInitializeWithChannelsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08\x63hannels\x18\x03 \x01(\t\x12\r\n\x05reset\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x90\x01\n\x1eInitializeWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"2\n\x0c\x43loseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rCloseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa2\x01\n\x1a\x43onfigureSourceModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x31\n\x0bsource_mode\x18\x02 \x01(\x0e\x32\x1a.nidcpower_grpc.SourceModeH\x00\x12\x19\n\x0fsource_mode_raw\x18\x03 \x01(\x11H\x00\x42\x12\n\x10source_mode_enum\"-\n\x1b\x43onfigureSourceModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1e\x43onfigureOutputFunctionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x08\x66unction\x18\x03 \x01(\x0e\x32\x1e.nidcpower_grpc.OutputFunctionH\x00\x12\x16\n\x0c\x66unction_raw\x18\x04 \x01(\x11H\x00\x42\x0f\n\rfunction_enum\"1\n\x1f\x43onfigureOutputFunctionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"j\n\x1d\x43onfigureOutputEnabledRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"0\n\x1e\x43onfigureOutputEnabledResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"u\n\x12SetSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\x01\x12\x15\n\rsource_delays\x18\x04 \x03(\x01\"%\n\x13SetSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"g\n\x1c\x43onfigureVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"/\n\x1d\x43onfigureVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xca\x01\n\x1c\x43onfigureCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x08\x62\x65havior\x18\x03 \x01(\x0e\x32$.nidcpower_grpc.CurrentLimitBehaviorH\x00\x12\x16\n\x0c\x62\x65havior_raw\x18\x04 \x01(\x11H\x00\x12\r\n\x05limit\x18\x05 \x01(\x01\x42\x0f\n\rbehavior_enum\"/\n\x1d\x43onfigureCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureVoltageLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureVoltageLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureCurrentLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureCurrentLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n ConfigureOutputResistanceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x12\n\nresistance\x18\x03 \x01(\x01\"3\n!ConfigureOutputResistanceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"g\n\x1c\x43onfigureCurrentLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"/\n\x1d\x43onfigureCurrentLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureCurrentLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureCurrentLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"g\n\x1c\x43onfigureVoltageLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"/\n\x1d\x43onfigureVoltageLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureVoltageLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureVoltageLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"4\n\"ConfigurePulseVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"4\n\"ConfigurePulseCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseVoltageLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseVoltageLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseCurrentLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseCurrentLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseCurrentLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"4\n\"ConfigurePulseCurrentLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseVoltageLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"4\n\"ConfigurePulseVoltageLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasCurrentLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasCurrentLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasVoltageLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasVoltageLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseCurrentLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseCurrentLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseVoltageLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseVoltageLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x91\x01\n\x1d\x43reateAdvancedSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rsequence_name\x18\x02 \x01(\t\x12\x15\n\rattribute_ids\x18\x03 \x03(\x11\x12\x1e\n\x16set_as_active_sequence\x18\x04 \x01(\x08\"0\n\x1e\x43reateAdvancedSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"c\n!CreateAdvancedSequenceStepRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12set_as_active_step\x18\x02 \x01(\x08\"4\n\"CreateAdvancedSequenceStepResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x1d\x44\x65leteAdvancedSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rsequence_name\x18\x02 \x01(\t\"0\n\x1e\x44\x65leteAdvancedSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc6\x01\n\x1c\x43onfigureApertureTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\raperture_time\x18\x03 \x01(\x01\x12\x32\n\x05units\x18\x04 \x01(\x0e\x32!.nidcpower_grpc.ApertureTimeUnitsH\x00\x12\x13\n\tunits_raw\x18\x05 \x01(\x11H\x00\x42\x0c\n\nunits_enum\"/\n\x1d\x43onfigureApertureTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x18\x43onfigureAutoZeroRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12-\n\tauto_zero\x18\x03 \x01(\x0e\x32\x18.nidcpower_grpc.AutoZeroH\x00\x12\x17\n\rauto_zero_raw\x18\x04 \x01(\x11H\x00\x42\x10\n\x0e\x61uto_zero_enum\"+\n\x19\x43onfigureAutoZeroResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcc\x01\n\"ConfigurePowerLineFrequencyRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x43\n\x13powerline_frequency\x18\x02 \x01(\x0e\x32$.nidcpower_grpc.PowerLineFrequenciesH\x00\x12!\n\x17powerline_frequency_raw\x18\x03 \x01(\x01H\x00\x42\x1a\n\x18powerline_frequency_enum\"5\n#ConfigurePowerLineFrequencyResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9c\x01\n\x15\x43onfigureSenseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12&\n\x05sense\x18\x03 \x01(\x0e\x32\x15.nidcpower_grpc.SenseH\x00\x12\x13\n\tsense_raw\x18\x04 \x01(\x11H\x00\x42\x0c\n\nsense_enum\"(\n\x16\x43onfigureSenseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x01\n\x0eMeasureRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12<\n\x10measurement_type\x18\x03 \x01(\x0e\x32 .nidcpower_grpc.MeasurementTypesH\x00\x12\x1e\n\x14measurement_type_raw\x18\x04 \x01(\x11H\x00\x42\x17\n\x15measurement_type_enum\"6\n\x0fMeasureResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0bmeasurement\x18\x02 \x01(\x01\"R\n\x16MeasureMultipleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"e\n\x17MeasureMultipleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1c\n\x14voltage_measurements\x18\x02 \x03(\x01\x12\x1c\n\x14\x63urrent_measurements\x18\x03 \x03(\x01\"p\n\x14\x46\x65tchMultipleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\r\n\x05\x63ount\x18\x04 \x01(\x11\"\x90\x01\n\x15\x46\x65tchMultipleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1c\n\x14voltage_measurements\x18\x02 \x03(\x01\x12\x1c\n\x14\x63urrent_measurements\x18\x03 \x03(\x01\x12\x15\n\rin_compliance\x18\x04 \x03(\x08\x12\x14\n\x0c\x61\x63tual_count\x18\x05 \x01(\x11\"U\n\x19MeasureMultipleLCRRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"d\n\x1aMeasureMultipleLCRResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x0cmeasurements\x18\x02 \x03(\x0b\x32 .nidcpower_grpc.NILCRMeasurement\"s\n\x17\x46\x65tchMultipleLCRRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\r\n\x05\x63ount\x18\x04 \x01(\x11\"x\n\x18\x46\x65tchMultipleLCRResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x0cmeasurements\x18\x02 \x03(\x0b\x32 .nidcpower_grpc.NILCRMeasurement\x12\x14\n\x0c\x61\x63tual_count\x18\x03 \x01(\x11\"T\n\x18QueryInComplianceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"B\n\x19QueryInComplianceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rin_compliance\x18\x02 \x01(\x08\"\xba\x01\n\x17QueryOutputStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x34\n\x0coutput_state\x18\x03 \x01(\x0e\x32\x1c.nidcpower_grpc.OutputStatesH\x00\x12\x1a\n\x10output_state_raw\x18\x04 \x01(\x11H\x00\x42\x13\n\x11output_state_enum\"<\n\x18QueryOutputStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x10\n\x08in_state\x18\x02 \x01(\x08\"\xe5\x01\n$QueryLatchedOutputCutoffStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x42\n\x14output_cutoff_reason\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.OutputCutoffReasonH\x00\x12\"\n\x18output_cutoff_reason_raw\x18\x04 \x01(\x11H\x00\x42\x1b\n\x19output_cutoff_reason_enum\"T\n%QueryLatchedOutputCutoffStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13output_cutoff_state\x18\x02 \x01(\x08\"\xe5\x01\n$ClearLatchedOutputCutoffStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x42\n\x14output_cutoff_reason\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.OutputCutoffReasonH\x00\x12\"\n\x18output_cutoff_reason_raw\x18\x04 \x01(\x11H\x00\x42\x1b\n\x19output_cutoff_reason_enum\"7\n%ClearLatchedOutputCutoffStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rCommitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\" \n\x0e\x43ommitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"5\n\x0fInitiateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\"\n\x10InitiateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0c\x41\x62ortRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rAbortResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"n\n\x1bQueryMaxCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rvoltage_level\x18\x03 \x01(\x01\"I\n\x1cQueryMaxCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11max_current_limit\x18\x02 \x01(\x01\"n\n\x1bQueryMaxVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rcurrent_limit\x18\x03 \x01(\x01\"I\n\x1cQueryMaxVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11max_voltage_level\x18\x02 \x01(\x01\"n\n\x1bQueryMinCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rvoltage_level\x18\x03 \x01(\x01\"I\n\x1cQueryMinCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11min_current_limit\x18\x02 \x01(\x01\"S\n\x17\x43\x61lSelfCalibrateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"*\n\x18\x43\x61lSelfCalibrateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"I\n#GetExtCalRecommendedIntervalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"F\n$GetExtCalRecommendedIntervalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x11\"E\n\x1fGetExtCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"z\n GetExtCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"C\n\x1dReadCurrentTemperatureRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x1eReadCurrentTemperatureResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\">\n\x18GetExtCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"@\n\x19GetExtCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"F\n GetSelfCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"{\n!GetSelfCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"?\n\x19GetSelfCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"A\n\x1aGetSelfCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"\xe1\x01\n(GetLCRCompensationLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12@\n\x11\x63ompensation_type\x18\x03 \x01(\x0e\x32#.nidcpower_grpc.LCRCompensationTypeH\x00\x12\x1f\n\x15\x63ompensation_type_raw\x18\x04 \x01(\x11H\x00\x42\x18\n\x16\x63ompensation_type_enum\"\x83\x01\n)GetLCRCompensationLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"\xb3\x01\n\'ConfigureDigitalEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\":\n(ConfigureDigitalEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n(ConfigureSoftwareEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n)ConfigureSoftwareEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1a\x44isableStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1b\x44isableStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n1ConfigureDigitalEdgeSequenceAdvanceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"D\n2ConfigureDigitalEdgeSequenceAdvanceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"X\n2ConfigureSoftwareEdgeSequenceAdvanceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n3ConfigureSoftwareEdgeSequenceAdvanceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"J\n$DisableSequenceAdvanceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"7\n%DisableSequenceAdvanceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x01\n(ConfigureDigitalEdgeSourceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\";\n)ConfigureDigitalEdgeSourceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"O\n)ConfigureSoftwareEdgeSourceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"<\n*ConfigureSoftwareEdgeSourceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"A\n\x1b\x44isableSourceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\".\n\x1c\x44isableSourceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x01\n)ConfigureDigitalEdgeMeasureTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"<\n*ConfigureDigitalEdgeMeasureTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"P\n*ConfigureSoftwareEdgeMeasureTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"=\n+ConfigureSoftwareEdgeMeasureTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb3\x01\n\'ConfigureDigitalEdgePulseTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\":\n(ConfigureDigitalEdgePulseTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n(ConfigureSoftwareEdgePulseTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n)ConfigureSoftwareEdgePulseTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1a\x44isablePulseTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1b\x44isablePulseTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc2\x01\n\x13\x45xportSignalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12.\n\x06signal\x18\x02 \x01(\x0e\x32\x1c.nidcpower_grpc.ExportSignalH\x00\x12\x14\n\nsignal_raw\x18\x03 \x01(\x11H\x00\x12\x19\n\x11signal_identifier\x18\x04 \x01(\t\x12\x17\n\x0foutput_terminal\x18\x05 \x01(\tB\r\n\x0bsignal_enum\"&\n\x14\x45xportSignalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x01\n\x1eSendSoftwareEdgeTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\x07trigger\x18\x02 \x01(\x0e\x32+.nidcpower_grpc.SendSoftwareEdgeTriggerTypeH\x00\x12\x15\n\x0btrigger_raw\x18\x03 \x01(\x11H\x00\x42\x0e\n\x0ctrigger_enum\"1\n\x1fSendSoftwareEdgeTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9e\x01\n\x13WaitForEventRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12)\n\x08\x65vent_id\x18\x02 \x01(\x0e\x32\x15.nidcpower_grpc.EventH\x00\x12\x16\n\x0c\x65vent_id_raw\x18\x03 \x01(\x11H\x00\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x42\x0f\n\revent_id_enum\"&\n\x14WaitForEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0e\x44isableRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0f\x44isableResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0cResetRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rResetResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"8\n\x12ResetDeviceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"%\n\x13ResetDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"5\n\x0fSelfTestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x10SelfTestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x18\n\x10self_test_result\x18\x02 \x01(\x11\x12\x19\n\x11self_test_message\x18\x03 \x01(\t\":\n\x14RevisionQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"f\n\x15RevisionQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1ainstrument_driver_revision\x18\x02 \x01(\t\x12\x19\n\x11\x66irmware_revision\x18\x03 \x01(\t\">\n\x18ResetWithDefaultsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19ResetWithDefaultsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"J\n\x15GetChannelNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\">\n\x16GetChannelNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"T\n\x1fGetChannelNameFromStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\t\"H\n GetChannelNameFromStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"B\n\x1cGetNextCoercionRecordRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"H\n\x1dGetNextCoercionRecordResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x63oercion_record\x18\x02 \x01(\t\"E\n\x1f\x43learInterchangeWarningsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"2\n ClearInterchangeWarningsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"B\n\x1cResetInterchangeCheckRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dResetInterchangeCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"F\n GetNextInterchangeWarningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"P\n!GetNextInterchangeWarningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13interchange_warning\x18\x02 \x01(\t\"5\n\x0fGetErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x10GetErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x11\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"7\n\x11\x43learErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"$\n\x12\x43learErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"M\n\x13\x45rrorMessageRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorMessageResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"\x91\x02\n\x1aSetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12H\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32-.nidcpower_grpc.NiDCPowerInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"-\n\x1bSetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xad\x01\n\x1aSetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x03\"-\n\x1bSetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x93\x02\n\x1bSetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12I\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32..nidcpower_grpc.NiDCPowerReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x1bSetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\t\".\n\x1cSetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc3\x01\n\x1cSetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dSetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x01\n\x1cSetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"/\n\x1dSetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x90\x01\n\x1aGetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"F\n\x1bGetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x11\"\x90\x01\n\x1aGetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"F\n\x1bGetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x03\"\x91\x01\n\x1bGetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"G\n\x1cGetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x01\"\x91\x01\n\x1bGetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"G\n\x1cGetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\t\"\x92\x01\n\x1cGetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"`\n\x1dGetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\x0f\x61ttribute_value\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x92\x01\n\x1cGetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"H\n\x1dGetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x08\"`\n\'ImportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ImportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"`\n\'ExportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ExportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"f\n)ImportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"<\n*ImportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"O\n)ExportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"S\n*ExportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"}\n!PerformLCROpenCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1e\n\x16\x61\x64\x64itional_frequencies\x18\x03 \x03(\x01\"4\n\"PerformLCROpenCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"~\n\"PerformLCRShortCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1e\n\x16\x61\x64\x64itional_frequencies\x18\x03 \x03(\x01\"5\n#PerformLCRShortCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa4\x01\n!PerformLCRLoadCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x45\n\x12\x63ompensation_spots\x18\x03 \x03(\x0b\x32).nidcpower_grpc.NILCRLoadCompensationSpot\"4\n\"PerformLCRLoadCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"v\n\x1f\x43onfigureLCRCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x19\n\x11\x63ompensation_data\x18\x03 \x01(\x0c\"2\n ConfigureLCRCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n,PerformLCROpenCustomCableCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"?\n-PerformLCROpenCustomCableCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"i\n-PerformLCRShortCustomCableCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"@\n.PerformLCRShortCustomCableCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Y\n\x1dGetLCRCompensationDataRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"K\n\x1eGetLCRCompensationDataResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11\x63ompensation_data\x18\x02 \x01(\x0c\"\xcc\x01\n(InitializeWithIndependentChannelsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\r\n\x05reset\x18\x03 \x01(\x08\x12\x15\n\roption_string\x18\x04 \x01(\t\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x9b\x01\n)InitializeWithIndependentChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xc4\x01\n&ConfigureSourceModeWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x31\n\x0bsource_mode\x18\x03 \x01(\x0e\x32\x1a.nidcpower_grpc.SourceModeH\x00\x12\x19\n\x0fsource_mode_raw\x18\x04 \x01(\x11H\x00\x42\x12\n\x10source_mode_enum\"9\n\'ConfigureSourceModeWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb3\x01\n)CreateAdvancedSequenceWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rsequence_name\x18\x03 \x01(\t\x12\x15\n\rattribute_ids\x18\x04 \x03(\x11\x12\x1e\n\x16set_as_active_sequence\x18\x05 \x01(\x08\"<\n*CreateAdvancedSequenceWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x01\n-CreateAdvancedSequenceStepWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1a\n\x12set_as_active_step\x18\x03 \x01(\x08\"@\n.CreateAdvancedSequenceStepWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8b\x01\n3CreateAdvancedSequenceCommitStepWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1a\n\x12set_as_active_step\x18\x03 \x01(\x08\"F\n4CreateAdvancedSequenceCommitStepWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"|\n)DeleteAdvancedSequenceWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rsequence_name\x18\x03 \x01(\t\"<\n*DeleteAdvancedSequenceWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"U\n\x19\x43ommitWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\",\n\x1a\x43ommitWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"W\n\x1bInitiateWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\".\n\x1cInitiateWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"T\n\x18\x41\x62ortWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"+\n\x19\x41\x62ortWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd5\x01\n3ConfigureDigitalEdgeStartTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"F\n4ConfigureDigitalEdgeStartTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n4ConfigureSoftwareEdgeStartTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"G\n5ConfigureSoftwareEdgeStartTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"b\n&DisableStartTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"9\n\'DisableStartTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdf\x01\n=ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"P\n>ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n>ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"Q\n?ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n0DisableSequenceAdvanceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"C\n1DisableSequenceAdvanceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd6\x01\n4ConfigureDigitalEdgeSourceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"G\n5ConfigureDigitalEdgeSourceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n5ConfigureSoftwareEdgeSourceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"H\n6ConfigureSoftwareEdgeSourceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"c\n\'DisableSourceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\":\n(DisableSourceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd7\x01\n5ConfigureDigitalEdgeMeasureTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"H\n6ConfigureDigitalEdgeMeasureTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"r\n6ConfigureSoftwareEdgeMeasureTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"I\n7ConfigureSoftwareEdgeMeasureTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd5\x01\n3ConfigureDigitalEdgePulseTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"F\n4ConfigureDigitalEdgePulseTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n4ConfigureSoftwareEdgePulseTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"G\n5ConfigureSoftwareEdgePulseTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"b\n&DisablePulseTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"9\n\'DisablePulseTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd8\x01\n6ConfigureDigitalEdgeShutdownTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"I\n7ConfigureDigitalEdgeShutdownTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"s\n7ConfigureSoftwareEdgeShutdownTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"J\n8ConfigureSoftwareEdgeShutdownTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"e\n)DisableShutdownTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"<\n*DisableShutdownTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe4\x01\n\x1f\x45xportSignalWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12.\n\x06signal\x18\x03 \x01(\x0e\x32\x1c.nidcpower_grpc.ExportSignalH\x00\x12\x14\n\nsignal_raw\x18\x04 \x01(\x11H\x00\x12\x19\n\x11signal_identifier\x18\x05 \x01(\t\x12\x17\n\x0foutput_terminal\x18\x06 \x01(\tB\r\n\x0bsignal_enum\"2\n ExportSignalWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcd\x01\n*SendSoftwareEdgeTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12>\n\x07trigger\x18\x03 \x01(\x0e\x32+.nidcpower_grpc.SendSoftwareEdgeTriggerTypeH\x00\x12\x15\n\x0btrigger_raw\x18\x04 \x01(\x11H\x00\x42\x0e\n\x0ctrigger_enum\"=\n+SendSoftwareEdgeTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc0\x01\n\x1fWaitForEventWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12)\n\x08\x65vent_id\x18\x03 \x01(\x0e\x32\x15.nidcpower_grpc.EventH\x00\x12\x16\n\x0c\x65vent_id_raw\x18\x04 \x01(\x11H\x00\x12\x0f\n\x07timeout\x18\x05 \x01(\x01\x42\x0f\n\revent_id_enum\"2\n WaitForEventWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"T\n\x18ResetWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"+\n\x19ResetWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eInvalidateAllAttributesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1fInvalidateAllAttributesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"o\n\x13\x43onfigureOvpRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\r\n\x05limit\x18\x04 \x01(\x01\"&\n\x14\x43onfigureOvpResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x11\x45rrorQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"O\n\x12\x45rrorQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x15\n\rerror_message\x18\x03 \x01(\t\"d\n(GetLCRCustomCableCompensationDataRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"c\n)GetLCRCustomCableCompensationDataResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12&\n\x1e\x63ustom_cable_compensation_data\x18\x02 \x01(\x0c\"\x8e\x01\n*ConfigureLCRCustomCableCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12&\n\x1e\x63ustom_cable_compensation_data\x18\x03 \x01(\x0c\"=\n+ConfigureLCRCustomCableCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05*\xc2\x65\n\x12NiDCPowerAttribute\x12#\n\x1fNIDCPOWER_ATTRIBUTE_UNSPECIFIED\x10\x00\x12%\n\x1fNIDCPOWER_ATTRIBUTE_RANGE_CHECK\x10\x92\x8b@\x12\x31\n+NIDCPOWER_ATTRIBUTE_QUERY_INSTRUMENT_STATUS\x10\x93\x8b@\x12\x1f\n\x19NIDCPOWER_ATTRIBUTE_CACHE\x10\x94\x8b@\x12\"\n\x1cNIDCPOWER_ATTRIBUTE_SIMULATE\x10\x95\x8b@\x12*\n$NIDCPOWER_ATTRIBUTE_RECORD_COERCIONS\x10\x96\x8b@\x12+\n%NIDCPOWER_ATTRIBUTE_INTERCHANGE_CHECK\x10\xa5\x8b@\x12\'\n!NIDCPOWER_ATTRIBUTE_CHANNEL_COUNT\x10\xdb\x8c@\x12\x30\n*NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_PREFIX\x10\xbe\x8d@\x12\x35\n/NIDCPOWER_ATTRIBUTE_SUPPORTED_INSTRUMENT_MODELS\x10\xd7\x8d@\x12,\n&NIDCPOWER_ATTRIBUTE_GROUP_CAPABILITIES\x10\xa1\x8e@\x12\x31\n+NIDCPOWER_ATTRIBUTE_INSTRUMENT_MANUFACTURER\x10\x8f\x8f@\x12*\n$NIDCPOWER_ATTRIBUTE_INSTRUMENT_MODEL\x10\x90\x8f@\x12\x36\n0NIDCPOWER_ATTRIBUTE_INSTRUMENT_FIRMWARE_REVISION\x10\x8e\x8f@\x12\x32\n,NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_REVISION\x10\xb7\x8f@\x12\x30\n*NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_VENDOR\x10\x91\x8f@\x12\x35\n/NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_DESCRIPTION\x10\x92\x8f@\x12\x42\n<NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION\x10\x93\x8f@\x12\x42\n<NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION\x10\x94\x8f@\x12\'\n!NIDCPOWER_ATTRIBUTE_SERIAL_NUMBER\x10\xc8\x99\x46\x12&\n NIDCPOWER_ATTRIBUTE_LOGICAL_NAME\x10\xc1\x8d@\x12\x30\n*NIDCPOWER_ATTRIBUTE_IO_RESOURCE_DESCRIPTOR\x10\xc0\x8d@\x12&\n NIDCPOWER_ATTRIBUTE_DRIVER_SETUP\x10\x97\x8b@\x12%\n\x1fNIDCPOWER_ATTRIBUTE_SOURCE_MODE\x10\xe6\x98\x46\x12)\n#NIDCPOWER_ATTRIBUTE_OUTPUT_FUNCTION\x10\xb8\x98\x46\x12(\n\"NIDCPOWER_ATTRIBUTE_OUTPUT_ENABLED\x10\xd6\xa5L\x12*\n$NIDCPOWER_ATTRIBUTE_OUTPUT_CONNECTED\x10\xec\x98\x46\x12+\n%NIDCPOWER_ATTRIBUTE_OUTPUT_RESISTANCE\x10\xed\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_TRANSIENT_RESPONSE\x10\xee\x98\x46\x12\x30\n*NIDCPOWER_ATTRIBUTE_VOLTAGE_GAIN_BANDWIDTH\x10\xf3\x98\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_VOLTAGE_COMPENSATION_FREQUENCY\x10\xf4\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_VOLTAGE_POLE_ZERO_RATIO\x10\xf5\x98\x46\x12\x30\n*NIDCPOWER_ATTRIBUTE_CURRENT_GAIN_BANDWIDTH\x10\xf6\x98\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_CURRENT_COMPENSATION_FREQUENCY\x10\xf7\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CURRENT_POLE_ZERO_RATIO\x10\xf8\x98\x46\x12<\n6NIDCPOWER_ATTRIBUTE_CONSTANT_RESISTANCE_GAIN_BANDWIDTH\x10\xa0\x9b\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_CONSTANT_RESISTANCE_COMPENSATION_FREQUENCY\x10\x9e\x9b\x46\x12=\n7NIDCPOWER_ATTRIBUTE_CONSTANT_RESISTANCE_POLE_ZERO_RATIO\x10\xa3\x9b\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_CONSTANT_POWER_GAIN_BANDWIDTH\x10\x9a\x9b\x46\x12?\n9NIDCPOWER_ATTRIBUTE_CONSTANT_POWER_COMPENSATION_FREQUENCY\x10\x98\x9b\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_CONSTANT_POWER_POLE_ZERO_RATIO\x10\x9d\x9b\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_VOLTAGE_LEVEL\x10\xd1\xa5L\x12\'\n!NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT\x10\xd5\xa5L\x12-\n\'NIDCPOWER_ATTRIBUTE_VOLTAGE_LEVEL_RANGE\x10\xb5\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_RANGE\x10\xb4\x98\x46\x12\x30\n*NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_BEHAVIOR\x10\xd4\xa5L\x12\x31\n+NIDCPOWER_ATTRIBUTE_VOLTAGE_LEVEL_AUTORANGE\x10\xbf\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_AUTORANGE\x10\xc0\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_HIGH\x10\xeb\x99\x46\x12+\n%NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_LOW\x10\xec\x99\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL\x10\xb9\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT\x10\xba\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL_RANGE\x10\xbb\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_RANGE\x10\xbc\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL_AUTORANGE\x10\xc1\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_AUTORANGE\x10\xc2\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_HIGH\x10\xe9\x99\x46\x12+\n%NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_LOW\x10\xea\x99\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL_RISING_SLEW_RATE\x10\x87\x9b\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL_FALLING_SLEW_RATE\x10\x88\x9b\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LEVEL\x10\x80\x99\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT\x10\x81\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LEVEL\x10\x82\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LIMIT\x10\x83\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LEVEL_RANGE\x10\x84\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT_RANGE\x10\x85\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT_HIGH\x10\xf1\x99\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT_LOW\x10\xf2\x99\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LIMIT_HIGH\x10\xf3\x99\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LIMIT_LOW\x10\xf4\x99\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LEVEL\x10\x86\x99\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT\x10\x87\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LEVEL\x10\x88\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LIMIT\x10\x89\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LEVEL_RANGE\x10\x8a\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT_RANGE\x10\x8b\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT_HIGH\x10\xed\x99\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT_LOW\x10\xee\x99\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LIMIT_HIGH\x10\xef\x99\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LIMIT_LOW\x10\xf0\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_CONSTANT_RESISTANCE_LEVEL\x10\xa1\x9b\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_CONSTANT_RESISTANCE_LEVEL_RANGE\x10\xa2\x9b\x46\x12;\n5NIDCPOWER_ATTRIBUTE_CONSTANT_RESISTANCE_CURRENT_LIMIT\x10\x9f\x9b\x46\x12.\n(NIDCPOWER_ATTRIBUTE_CONSTANT_POWER_LEVEL\x10\x9b\x9b\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_CONSTANT_POWER_LEVEL_RANGE\x10\x9c\x9b\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_CONSTANT_POWER_CURRENT_LIMIT\x10\x99\x9b\x46\x12&\n NIDCPOWER_ATTRIBUTE_SOURCE_DELAY\x10\xe3\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_OVERRANGING_ENABLED\x10\xb7\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_OUTPUT_CAPACITANCE\x10\xbe\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_SEQUENCE_LOOP_COUNT\x10\xc9\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_SEQUENCE_LOOP_COUNT_IS_FINITE\x10\xfe\x98\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_COMPLIANCE_LIMIT_SYMMETRY\x10\xe8\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_SEQUENCE_STEP_DELTA_TIME\x10\xf6\x99\x46\x12:\n4NIDCPOWER_ATTRIBUTE_SEQUENCE_STEP_DELTA_TIME_ENABLED\x10\xf7\x99\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_ACTUAL_POWER_ALLOCATION\x10\xfd\x99\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_REQUESTED_POWER_ALLOCATION\x10\xfe\x99\x46\x12/\n)NIDCPOWER_ATTRIBUTE_POWER_ALLOCATION_MODE\x10\xff\x99\x46\x12)\n#NIDCPOWER_ATTRIBUTE_MERGED_CHANNELS\x10\xa9\x9a\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CONDUCTION_VOLTAGE_MODE\x10\x8e\x9b\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_CONDUCTION_VOLTAGE_ON_THRESHOLD\x10\x8f\x9b\x46\x12:\n4NIDCPOWER_ATTRIBUTE_CONDUCTION_VOLTAGE_OFF_THRESHOLD\x10\x90\x9b\x46\x12(\n\"NIDCPOWER_ATTRIBUTE_OUTPUT_SHORTED\x10\xa4\x9b\x46\x12*\n$NIDCPOWER_ATTRIBUTE_PULSE_BIAS_DELAY\x10\x8c\x99\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_PULSE_ON_TIME\x10\x8d\x99\x46\x12(\n\"NIDCPOWER_ATTRIBUTE_PULSE_OFF_TIME\x10\x8e\x99\x46\x12%\n\x1fNIDCPOWER_ATTRIBUTE_OVP_ENABLED\x10\xd2\xa5L\x12#\n\x1dNIDCPOWER_ATTRIBUTE_OVP_LIMIT\x10\xd3\xa5L\x12\x1f\n\x19NIDCPOWER_ATTRIBUTE_SENSE\x10\xbd\x98\x46\x12#\n\x1dNIDCPOWER_ATTRIBUTE_AUTO_ZERO\x10\xe7\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_APERTURE_TIME\x10\xea\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_APERTURE_TIME_UNITS\x10\xeb\x98\x46\x12.\n(NIDCPOWER_ATTRIBUTE_POWER_LINE_FREQUENCY\x10\xc4\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_SAMPLES_TO_AVERAGE\x10\xb3\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_FETCH_BACKLOG\x10\xe8\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_APERTURE_TIME_AUTO_MODE\x10\xea\x9a\x46\x12#\n\x1dNIDCPOWER_ATTRIBUTE_AUTORANGE\x10\xa4\x9a\x46\x12&\n NIDCPOWER_ATTRIBUTE_MEASURE_WHEN\x10\xe9\x98\x46\x12:\n4NIDCPOWER_ATTRIBUTE_RESET_AVERAGE_BEFORE_MEASUREMENT\x10\xb6\x98\x46\x12/\n)NIDCPOWER_ATTRIBUTE_MEASURE_RECORD_LENGTH\x10\xef\x98\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_MEASURE_RECORD_LENGTH_IS_FINITE\x10\xf0\x98\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_MEASURE_RECORD_DELTA_TIME\x10\xf1\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_DC_NOISE_REJECTION\x10\xf2\x98\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_SELF_CALIBRATION_PERSISTENCE\x10\xf9\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_MEASURE_BUFFER_SIZE\x10\xfd\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_AUTORANGE_BEHAVIOR\x10\xa5\x9a\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_AUTORANGE_APERTURE_TIME_MODE\x10\xa6\x9a\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_APERTURE_TIME\x10\xa7\x9a\x46\x12?\n9NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_APERTURE_TIME_UNITS\x10\xa8\x9a\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_CURRENT_RANGE\x10\xaf\x9a\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_VOLTAGE_RANGE\x10\xb0\x9a\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_AUTORANGE_THRESHOLD_MODE\x10\xb1\x9a\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_AUTORANGE_MAXIMUM_DELAY_AFTER_RANGE_CHANGE\x10\xf2\x9a\x46\x12,\n&NIDCPOWER_ATTRIBUTE_START_TRIGGER_TYPE\x10\xc5\x98\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_EDGE\x10\xc6\x98\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_INPUT_TERMINAL\x10\xc7\x98\x46\x12@\n:NIDCPOWER_ATTRIBUTE_EXPORTED_START_TRIGGER_OUTPUT_TERMINAL\x10\xc8\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_SOURCE_TRIGGER_TYPE\x10\xce\x98\x46\x12:\n4NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SOURCE_TRIGGER_EDGE\x10\xcf\x98\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SOURCE_TRIGGER_INPUT_TERMINAL\x10\xd0\x98\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_EXPORTED_SOURCE_TRIGGER_OUTPUT_TERMINAL\x10\xd1\x98\x46\x12.\n(NIDCPOWER_ATTRIBUTE_MEASURE_TRIGGER_TYPE\x10\xd2\x98\x46\x12;\n5NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_MEASURE_TRIGGER_EDGE\x10\xd3\x98\x46\x12\x45\n?NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_MEASURE_TRIGGER_INPUT_TERMINAL\x10\xd4\x98\x46\x12\x42\n<NIDCPOWER_ATTRIBUTE_EXPORTED_MEASURE_TRIGGER_OUTPUT_TERMINAL\x10\xd5\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_SEQUENCE_ADVANCE_TRIGGER_TYPE\x10\xca\x98\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SEQUENCE_ADVANCE_TRIGGER_EDGE\x10\xcb\x98\x46\x12N\nHNIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SEQUENCE_ADVANCE_TRIGGER_INPUT_TERMINAL\x10\xcc\x98\x46\x12K\nENIDCPOWER_ATTRIBUTE_EXPORTED_SEQUENCE_ADVANCE_TRIGGER_OUTPUT_TERMINAL\x10\xcd\x98\x46\x12?\n9NIDCPOWER_ATTRIBUTE_SOURCE_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\xdb\x98\x46\x12>\n8NIDCPOWER_ATTRIBUTE_SOURCE_COMPLETE_EVENT_PULSE_POLARITY\x10\xd9\x98\x46\x12;\n5NIDCPOWER_ATTRIBUTE_SOURCE_COMPLETE_EVENT_PULSE_WIDTH\x10\xda\x98\x46\x12@\n:NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\xdf\x98\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_DELAY\x10\xde\x98\x46\x12?\n9NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_PULSE_POLARITY\x10\xdc\x98\x46\x12<\n6NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_PULSE_WIDTH\x10\xdd\x98\x46\x12K\nENIDCPOWER_ATTRIBUTE_SEQUENCE_ITERATION_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\xd8\x98\x46\x12J\nDNIDCPOWER_ATTRIBUTE_SEQUENCE_ITERATION_COMPLETE_EVENT_PULSE_POLARITY\x10\xd6\x98\x46\x12G\nANIDCPOWER_ATTRIBUTE_SEQUENCE_ITERATION_COMPLETE_EVENT_PULSE_WIDTH\x10\xd7\x98\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_SEQUENCE_ENGINE_DONE_EVENT_OUTPUT_TERMINAL\x10\xe2\x98\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_SEQUENCE_ENGINE_DONE_EVENT_PULSE_POLARITY\x10\xe0\x98\x46\x12@\n:NIDCPOWER_ATTRIBUTE_SEQUENCE_ENGINE_DONE_EVENT_PULSE_WIDTH\x10\xe1\x98\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_ACTIVE_ADVANCED_SEQUENCE\x10\xfa\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_ACTIVE_ADVANCED_SEQUENCE_STEP\x10\xfb\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_PULSE_TRIGGER_TYPE\x10\x8f\x99\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_PULSE_TRIGGER_EDGE\x10\x90\x99\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_PULSE_TRIGGER_INPUT_TERMINAL\x10\x91\x99\x46\x12@\n:NIDCPOWER_ATTRIBUTE_EXPORTED_PULSE_TRIGGER_OUTPUT_TERMINAL\x10\x92\x99\x46\x12>\n8NIDCPOWER_ATTRIBUTE_PULSE_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\x93\x99\x46\x12=\n7NIDCPOWER_ATTRIBUTE_PULSE_COMPLETE_EVENT_PULSE_POLARITY\x10\x94\x99\x46\x12:\n4NIDCPOWER_ATTRIBUTE_PULSE_COMPLETE_EVENT_PULSE_WIDTH\x10\x95\x99\x46\x12G\nANIDCPOWER_ATTRIBUTE_READY_FOR_PULSE_TRIGGER_EVENT_OUTPUT_TERMINAL\x10\x96\x99\x46\x12\x46\n@NIDCPOWER_ATTRIBUTE_READY_FOR_PULSE_TRIGGER_EVENT_PULSE_POLARITY\x10\x97\x99\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_READY_FOR_PULSE_TRIGGER_EVENT_PULSE_WIDTH\x10\x98\x99\x46\x12/\n)NIDCPOWER_ATTRIBUTE_SHUTDOWN_TRIGGER_TYPE\x10\xc3\x9a\x46\x12<\n6NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SHUTDOWN_TRIGGER_EDGE\x10\xc4\x9a\x46\x12\x46\n@NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SHUTDOWN_TRIGGER_INPUT_TERMINAL\x10\xc5\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_INTERLOCK_INPUT_OPEN\x10\x99\x99\x46\x12&\n NIDCPOWER_ATTRIBUTE_POWER_SOURCE\x10\xb0\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_POWER_SOURCE_IN_USE\x10\xb1\x98\x46\x12:\n4NIDCPOWER_ATTRIBUTE_AUXILIARY_POWER_SOURCE_AVAILABLE\x10\xb2\x98\x46\x12)\n#NIDCPOWER_ATTRIBUTE_ISOLATION_STATE\x10\xde\x9a\x46\x12)\n#NIDCPOWER_ATTRIBUTE_INSTRUMENT_MODE\x10\x80\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_STIMULUS_FUNCTION\x10\x81\x9a\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_LCR_FREQUENCY\x10\x82\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_VOLTAGE_AMPLITUDE\x10\x83\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_CURRENT_AMPLITUDE\x10\x84\x9a\x46\x12,\n&NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_SOURCE\x10\x85\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_VOLTAGE_LEVEL\x10\x86\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_CURRENT_LEVEL\x10\x87\x9a\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_LCR_IMPEDANCE_AUTO_RANGE\x10\x88\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_IMPEDANCE_RANGE\x10\x89\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_MEASUREMENT_TIME\x10\x8a\x9a\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_LCR_OPEN_COMPENSATION_ENABLED\x10\x8c\x9a\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_LCR_SHORT_COMPENSATION_ENABLED\x10\x8d\x9a\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_LCR_LOAD_COMPENSATION_ENABLED\x10\x8e\x9a\x46\x12\x46\n@NIDCPOWER_ATTRIBUTE_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE\x10\x8f\x9a\x46\x12\x35\n/NIDCPOWER_ATTRIBUTE_LCR_CUSTOM_MEASUREMENT_TIME\x10\xb2\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_OPEN_CONDUCTANCE\x10\xb5\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_OPEN_SUSCEPTANCE\x10\xb6\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_SHORT_RESISTANCE\x10\xb7\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_SHORT_REACTANCE\x10\xb8\x9a\x46\x12+\n%NIDCPOWER_ATTRIBUTE_LCR_VOLTAGE_RANGE\x10\xb9\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_VOLTAGE_RANGE\x10\xba\x9a\x46\x12+\n%NIDCPOWER_ATTRIBUTE_LCR_CURRENT_RANGE\x10\xbb\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_CURRENT_RANGE\x10\xc2\x9a\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_LCR_MEASURED_LOAD_RESISTANCE\x10\xbc\x9a\x46\x12\x35\n/NIDCPOWER_ATTRIBUTE_LCR_MEASURED_LOAD_REACTANCE\x10\xbd\x9a\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_LCR_ACTUAL_LOAD_RESISTANCE\x10\xbe\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_ACTUAL_LOAD_REACTANCE\x10\xbf\x9a\x46\x12&\n NIDCPOWER_ATTRIBUTE_CABLE_LENGTH\x10\xc6\x9a\x46\x12\x35\n/NIDCPOWER_ATTRIBUTE_LCR_AUTOMATIC_LEVEL_CONTROL\x10\xd2\x9a\x46\x12=\n7NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_AUTOMATIC_LEVEL_CONTROL\x10\xd3\x9a\x46\x12\x45\n?NIDCPOWER_ATTRIBUTE_LCR_SHORT_CUSTOM_CABLE_COMPENSATION_ENABLED\x10\xdb\x9a\x46\x12>\n8NIDCPOWER_ATTRIBUTE_LCR_AC_ELECTRICAL_CABLE_LENGTH_DELAY\x10\xe5\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_SOURCE_DELAY_MODE\x10\xeb\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_LOAD_RESISTANCE\x10\xee\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_LOAD_INDUCTANCE\x10\xef\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_LOAD_CAPACITANCE\x10\xf0\x9a\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_LCR_IMPEDANCE_RANGE_SOURCE\x10\xf1\x9a\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_TRANSIENT_RESPONSE\x10\x8b\x9b\x46\x12/\n)NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_ENABLED\x10\x9b\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_OUTPUT_LIMIT_HIGH\x10\x9c\x9a\x46\x12\x42\n<NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_MEASURE_LIMIT_HIGH\x10\x9d\x9a\x46\x12@\n:NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_CHANGE_LIMIT_LOW\x10\x9e\x9a\x46\x12@\n:NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_CHANGE_LIMIT_LOW\x10\x9f\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_OVERRANGE_ENABLED\x10\xa0\x9a\x46\x12@\n:NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_OUTPUT_LIMIT_LOW\x10\xd4\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_MEASURE_LIMIT_LOW\x10\xd5\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_CHANGE_LIMIT_HIGH\x10\xd6\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_CHANGE_LIMIT_HIGH\x10\xd7\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_DELAY\x10\xdc\x9a\x46\x12\x42\n<NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_MEASURE_LIMIT_HIGH\x10\x95\x9b\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_MEASURE_LIMIT_LOW\x10\x96\x9b\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_AC_DITHER_ENABLED\x10\x8c\x9b\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_LCR_SOURCE_APERTURE_TIME\x10\x8d\x9b\x46\x12.\n(NIDCPOWER_ATTRIBUTE_OCP_ERROR_PERCENTAGE\x10\xf8\x99\x46\x12,\n&NIDCPOWER_ATTRIBUTE_SUPPORT_OUTPUT_DMA\x10\xff\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_INSTRUMENT_API_SESSION_HANDLE\x10\x9e\x99\x46\x12=\n7NIDCPOWER_ATTRIBUTE_ACTUAL_VOLTAGE_RANGE_FOR_LAST_FETCH\x10\xb3\x9a\x46\x12=\n7NIDCPOWER_ATTRIBUTE_ACTUAL_CURRENT_RANGE_FOR_LAST_FETCH\x10\xb4\x9a\x46\x12T\nNNIDCPOWER_ATTRIBUTE_WAS_SESSION_OPENED_BY_INITIALIZE_WITH_INDEPENDENT_CHANNELS\x10\x9f\x99\x46*\x88\x01\n\x14\x43urrentLimitBehavior\x12\x39\n5CURRENT_LIMIT_BEHAVIOR_NIDCPOWER_VAL_CURRENT_REGULATE\x10\x00\x12\x35\n1CURRENT_LIMIT_BEHAVIOR_NIDCPOWER_VAL_CURRENT_TRIP\x10\x01*\xd1\x02\n\x0cOutputStates\x12\x37\n3OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_CONSTANT_VOLTAGE\x10\x00\x12\x37\n3OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_CONSTANT_CURRENT\x10\x01\x12\x33\n/OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_OVER_VOLTAGE\x10\x02\x12\x33\n/OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_OVER_CURRENT\x10\x03\x12\x32\n.OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_UNREGULATED\x10\x04\x12\x31\n,OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_INHIBITED\x10\x8b\t*|\n\x10MeasurementTypes\x12\x33\n/MEASUREMENT_TYPES_NIDCPOWER_VAL_MEASURE_CURRENT\x10\x00\x12\x33\n/MEASUREMENT_TYPES_NIDCPOWER_VAL_MEASURE_VOLTAGE\x10\x01*\xde\x02\n\x0eOutputFunction\x12\x1f\n\x1bOUTPUT_FUNCTION_UNSPECIFIED\x10\x00\x12-\n(OUTPUT_FUNCTION_NIDCPOWER_VAL_DC_VOLTAGE\x10\xee\x07\x12-\n(OUTPUT_FUNCTION_NIDCPOWER_VAL_DC_CURRENT\x10\xef\x07\x12\x30\n+OUTPUT_FUNCTION_NIDCPOWER_VAL_PULSE_VOLTAGE\x10\x99\x08\x12\x30\n+OUTPUT_FUNCTION_NIDCPOWER_VAL_PULSE_CURRENT\x10\x9a\x08\x12\x36\n1OUTPUT_FUNCTION_NIDCPOWER_VAL_CONSTANT_RESISTANCE\x10\x89\t\x12\x31\n,OUTPUT_FUNCTION_NIDCPOWER_VAL_CONSTANT_POWER\x10\x8a\t*_\n\x05Sense\x12\x15\n\x11SENSE_UNSPECIFIED\x10\x00\x12\x1e\n\x19SENSE_NIDCPOWER_VAL_LOCAL\x10\xf0\x07\x12\x1f\n\x1aSENSE_NIDCPOWER_VAL_REMOTE\x10\xf1\x07*|\n\x0b\x44igitalEdge\x12\x1c\n\x18\x44IGITAL_EDGE_UNSPECIFIED\x10\x00\x12&\n!DIGITAL_EDGE_NIDCPOWER_VAL_RISING\x10\xf8\x07\x12\'\n\"DIGITAL_EDGE_NIDCPOWER_VAL_FALLING\x10\xf9\x07*\x7f\n\nSourceMode\x12\x1b\n\x17SOURCE_MODE_UNSPECIFIED\x10\x00\x12+\n&SOURCE_MODE_NIDCPOWER_VAL_SINGLE_POINT\x10\xfc\x07\x12\'\n\"SOURCE_MODE_NIDCPOWER_VAL_SEQUENCE\x10\xfd\x07*n\n\x08\x41utoZero\x12\x1f\n\x1b\x41UTO_ZERO_NIDCPOWER_VAL_OFF\x10\x00\x12!\n\x1c\x41UTO_ZERO_NIDCPOWER_VAL_ONCE\x10\x80\x08\x12\x1e\n\x1a\x41UTO_ZERO_NIDCPOWER_VAL_ON\x10\x01*\xa4\x01\n\x14PowerLineFrequencies\x12&\n\"POWER_LINE_FREQUENCIES_UNSPECIFIED\x10\x00\x12\x31\n-POWER_LINE_FREQUENCIES_NIDCPOWER_VAL_50_HERTZ\x10\x32\x12\x31\n-POWER_LINE_FREQUENCIES_NIDCPOWER_VAL_60_HERTZ\x10<*\xa2\x01\n\x11\x41pertureTimeUnits\x12#\n\x1f\x41PERTURE_TIME_UNITS_UNSPECIFIED\x10\x00\x12.\n)APERTURE_TIME_UNITS_NIDCPOWER_VAL_SECONDS\x10\x84\x08\x12\x38\n3APERTURE_TIME_UNITS_NIDCPOWER_VAL_POWER_LINE_CYCLES\x10\x85\x08*\xc7\x05\n\x0c\x45xportSignal\x12\x1d\n\x19\x45XPORT_SIGNAL_UNSPECIFIED\x10\x00\x12\x36\n1EXPORT_SIGNAL_NIDCPOWER_VAL_SOURCE_COMPLETE_EVENT\x10\x86\x08\x12\x37\n2EXPORT_SIGNAL_NIDCPOWER_VAL_MEASURE_COMPLETE_EVENT\x10\x87\x08\x12\x42\n=EXPORT_SIGNAL_NIDCPOWER_VAL_SEQUENCE_ITERATION_COMPLETE_EVENT\x10\x88\x08\x12;\n6EXPORT_SIGNAL_NIDCPOWER_VAL_SEQUENCE_ENGINE_DONE_EVENT\x10\x89\x08\x12\x35\n0EXPORT_SIGNAL_NIDCPOWER_VAL_PULSE_COMPLETE_EVENT\x10\x9b\x08\x12>\n9EXPORT_SIGNAL_NIDCPOWER_VAL_READY_FOR_PULSE_TRIGGER_EVENT\x10\x9c\x08\x12.\n)EXPORT_SIGNAL_NIDCPOWER_VAL_START_TRIGGER\x10\x8a\x08\x12/\n*EXPORT_SIGNAL_NIDCPOWER_VAL_SOURCE_TRIGGER\x10\x8b\x08\x12\x30\n+EXPORT_SIGNAL_NIDCPOWER_VAL_MEASURE_TRIGGER\x10\x8c\x08\x12\x39\n4EXPORT_SIGNAL_NIDCPOWER_VAL_SEQUENCE_ADVANCE_TRIGGER\x10\x8d\x08\x12.\n)EXPORT_SIGNAL_NIDCPOWER_VAL_PULSE_TRIGGER\x10\x9d\x08\x12\x31\n,EXPORT_SIGNAL_NIDCPOWER_VAL_SHUTDOWN_TRIGGER\x10\xde\x08*\x81\n\n\x12OutputCutoffReason\x12$\n OUTPUT_CUTOFF_REASON_UNSPECIFIED\x10\x00\x12H\n;OUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_ALL\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_OUTPUT_HIGH\x10\x01\x12N\nJOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_OUTPUT_LOW\x10\x02\x12P\nLOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_MEASURE_HIGH\x10\x04\x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_MEASURE_LOW\x10\x08\x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_CHANGE_HIGH\x10\x10\x12N\nJOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_CHANGE_LOW\x10 \x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_CHANGE_HIGH\x10@\x12O\nJOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_CHANGE_LOW\x10\x80\x01\x12N\nIOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_SATURATED\x10\x80\x02\x12N\nIOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_SATURATED\x10\x80\x04\x12Q\nLOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_MEASURE_HIGH\x10\x80\x08\x12P\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_MEASURE_LOW\x10\x80\x10\x12W\nROUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_SELF_TEST_MEASUREMENT_HIGH\x10\x80 \x12V\nQOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_SELF_TEST_MEASUREMENT_LOW\x10\x80@*\x84\x03\n\x13LCRCompensationType\x12%\n!LCR_COMPENSATION_TYPE_UNSPECIFIED\x10\x00\x12:\n5LCR_COMPENSATION_TYPE_NIDCPOWER_VAL_OPEN_COMPENSATION\x10\xea\x08\x12;\n6LCR_COMPENSATION_TYPE_NIDCPOWER_VAL_SHORT_COMPENSATION\x10\xeb\x08\x12:\n5LCR_COMPENSATION_TYPE_NIDCPOWER_VAL_LOAD_COMPENSATION\x10\xec\x08\x12G\nBLCR_COMPENSATION_TYPE_NIDCPOWER_VAL_OPEN_CUSTOM_CABLE_COMPENSATION\x10\xed\x08\x12H\nCLCR_COMPENSATION_TYPE_NIDCPOWER_VAL_SHORT_CUSTOM_CABLE_COMPENSATION\x10\xee\x08*\xb3\x02\n\x05\x45vent\x12\x15\n\x11\x45VENT_UNSPECIFIED\x10\x00\x12(\n#EVENT_NIDCPOWER_VAL_SOURCE_COMPLETE\x10\x86\x08\x12)\n$EVENT_NIDCPOWER_VAL_MEASURE_COMPLETE\x10\x87\x08\x12\x34\n/EVENT_NIDCPOWER_VAL_SEQUENCE_ITERATION_COMPLETE\x10\x88\x08\x12-\n(EVENT_NIDCPOWER_VAL_SEQUENCE_ENGINE_DONE\x10\x89\x08\x12\'\n\"EVENT_NIDCPOWER_VAL_PULSE_COMPLETE\x10\x9b\x08\x12\x30\n+EVENT_NIDCPOWER_VAL_READY_FOR_PULSE_TRIGGER\x10\x9c\x08*\xbb\x03\n\x1bSendSoftwareEdgeTriggerType\x12/\n+SEND_SOFTWARE_EDGE_TRIGGER_TYPE_UNSPECIFIED\x10\x00\x12\x38\n3SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_START\x10\x8a\x08\x12\x39\n4SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_SOURCE\x10\x8b\x08\x12:\n5SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_MEASURE\x10\x8c\x08\x12\x43\n>SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_SEQUENCE_ADVANCE\x10\x8d\x08\x12\x38\n3SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_PULSE\x10\x9d\x08\x12;\n6SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_SHUTDOWN\x10\xde\x08*\x8e\x31\n\x1dNiDCPowerInt32AttributeValues\x12\x1f\n\x1bNIDCPOWER_INT32_UNSPECIFIED\x10\x00\x12L\nGNIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_OFF\x10\xef\x08\x12N\nINIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_SHORT\x10\xf0\x08\x12O\nJNIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_NORMAL\x10\xf1\x08\x12M\nHNIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_LONG\x10\xf2\x08\x12\x34\n/NIDCPOWER_INT32_APERTURE_TIME_UNITS_VAL_SECONDS\x10\x84\x08\x12>\n9NIDCPOWER_INT32_APERTURE_TIME_UNITS_VAL_POWER_LINE_CYCLES\x10\x85\x08\x12%\n!NIDCPOWER_INT32_AUTO_ZERO_VAL_OFF\x10\x00\x12\'\n\"NIDCPOWER_INT32_AUTO_ZERO_VAL_ONCE\x10\x80\x08\x12$\n NIDCPOWER_INT32_AUTO_ZERO_VAL_ON\x10\x01\x12H\nCNIDCPOWER_INT32_AUTORANGE_APERTURE_TIME_MODE_VAL_APERTURE_TIME_AUTO\x10\xd6\x08\x12J\nENIDCPOWER_INT32_AUTORANGE_APERTURE_TIME_MODE_VAL_APERTURE_TIME_CUSTOM\x10\xd7\x08\x12G\nBNIDCPOWER_INT32_AUTORANGE_BEHAVIOR_VAL_RANGE_UP_TO_LIMIT_THEN_DOWN\x10\xd3\x08\x12\x34\n/NIDCPOWER_INT32_AUTORANGE_BEHAVIOR_VAL_RANGE_UP\x10\xd4\x08\x12=\n8NIDCPOWER_INT32_AUTORANGE_BEHAVIOR_VAL_RANGE_UP_AND_DOWN\x10\xd5\x08\x12G\nBNIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_NORMAL\x10\xd8\x08\x12J\nENIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_FAST_STEP\x10\xd9\x08\x12P\nKNIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_HIGH_HYSTERESIS\x10\xda\x08\x12R\nMNIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_MEDIUM_HYSTERESIS\x10\xdb\x08\x12\x45\n@NIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_HOLD\x10\xdc\x08\x12,\n\'NIDCPOWER_INT32_CABLE_LENGTH_VAL_ZERO_M\x10\xe1\x08\x12\x36\n1NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_0_5M\x10\x81\t\x12\x34\n/NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_1M\x10\xe2\x08\x12\x34\n/NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_2M\x10\xe3\x08\x12\x34\n/NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_4M\x10\xe4\x08\x12=\n8NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_TRIAXIAL_1M\x10\xf3\x08\x12=\n8NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_TRIAXIAL_2M\x10\xf4\x08\x12=\n8NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_TRIAXIAL_4M\x10\xf5\x08\x12<\n7NIDCPOWER_INT32_CABLE_LENGTH_VAL_CUSTOM_ONBOARD_STORAGE\x10\xe5\x08\x12:\n5NIDCPOWER_INT32_CABLE_LENGTH_VAL_CUSTOM_AS_CONFIGURED\x10\xe6\x08\x12;\n7NIDCPOWER_INT32_COMPLIANCE_LIMIT_SYMMETRY_VAL_SYMMETRIC\x10\x00\x12<\n8NIDCPOWER_INT32_COMPLIANCE_LIMIT_SYMMETRY_VAL_ASYMMETRIC\x10\x01\x12R\nMNIDCPOWER_INT32_CONDUCTION_VOLTAGE_MODE_VAL_CONDUCTION_VOLTAGE_MODE_AUTOMATIC\x10\x83\t\x12P\nKNIDCPOWER_INT32_CONDUCTION_VOLTAGE_MODE_VAL_CONDUCTION_VOLTAGE_MODE_ENABLED\x10\x84\t\x12Q\nLNIDCPOWER_INT32_CONDUCTION_VOLTAGE_MODE_VAL_CONDUCTION_VOLTAGE_MODE_DISABLED\x10\x85\t\x12?\n;NIDCPOWER_INT32_CURRENT_LIMIT_BEHAVIOR_VAL_CURRENT_REGULATE\x10\x00\x12;\n7NIDCPOWER_INT32_CURRENT_LIMIT_BEHAVIOR_VAL_CURRENT_TRIP\x10\x01\x12K\nFNIDCPOWER_INT32_DC_NOISE_REJECTION_VAL_DC_NOISE_REJECTION_SECOND_ORDER\x10\x93\x08\x12\x45\n@NIDCPOWER_INT32_DC_NOISE_REJECTION_VAL_DC_NOISE_REJECTION_NORMAL\x10\x94\x08\x12,\n\'NIDCPOWER_INT32_DIGITAL_EDGE_VAL_RISING\x10\xf8\x07\x12-\n(NIDCPOWER_INT32_DIGITAL_EDGE_VAL_FALLING\x10\xf9\x07\x12/\n*NIDCPOWER_INT32_INSTRUMENT_MODE_VAL_SMU_PS\x10\xa5\x08\x12,\n\'NIDCPOWER_INT32_INSTRUMENT_MODE_VAL_LCR\x10\xa6\x08\x12/\n*NIDCPOWER_INT32_INSTRUMENT_MODE_VAL_E_LOAD\x10\x82\t\x12\x31\n,NIDCPOWER_INT32_ISOLATION_STATE_VAL_ISOLATED\x10\xe8\x08\x12\x35\n0NIDCPOWER_INT32_ISOLATION_STATE_VAL_NON_ISOLATED\x10\xe9\x08\x12\x37\n3NIDCPOWER_INT32_LCR_AUTOMATIC_LEVEL_CONTROL_VAL_OFF\x10\x00\x12\x36\n2NIDCPOWER_INT32_LCR_AUTOMATIC_LEVEL_CONTROL_VAL_ON\x10\x01\x12\x36\n1NIDCPOWER_INT32_LCRDC_BIAS_SOURCE_VAL_DC_BIAS_OFF\x10\xa9\x08\x12:\n5NIDCPOWER_INT32_LCRDC_BIAS_SOURCE_VAL_DC_BIAS_VOLTAGE\x10\xaa\x08\x12:\n5NIDCPOWER_INT32_LCRDC_BIAS_SOURCE_VAL_DC_BIAS_CURRENT\x10\xab\x08\x12\\\nWNIDCPOWER_INT32_LCRDC_BIAS_TRANSIENT_RESPONSE_VAL_LCR_DC_BIAS_TRANSIENT_RESPONSE_NORMAL\x10\xff\x08\x12\\\nWNIDCPOWER_INT32_LCRDC_BIAS_TRANSIENT_RESPONSE_VAL_LCR_DC_BIAS_TRANSIENT_RESPONSE_CUSTOM\x10\x80\t\x12@\n;NIDCPOWER_INT32_LCR_IMPEDANCE_AUTO_RANGE_VAL_AUTO_RANGE_OFF\x10\xac\x08\x12?\n:NIDCPOWER_INT32_LCR_IMPEDANCE_AUTO_RANGE_VAL_AUTO_RANGE_ON\x10\xae\x08\x12G\nBNIDCPOWER_INT32_LCR_IMPEDANCE_RANGE_SOURCE_VAL_LCR_IMPEDANCE_RANGE\x10\xf6\x08\x12J\nENIDCPOWER_INT32_LCR_IMPEDANCE_RANGE_SOURCE_VAL_LCR_LOAD_CONFIGURATION\x10\xf7\x08\x12\x44\n?NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_SHORT\x10\xaf\x08\x12\x45\n@NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_MEDIUM\x10\xb0\x08\x12\x43\n>NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_LONG\x10\xb1\x08\x12\x45\n@NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_CUSTOM\x10\xdd\x08\x12U\nPNIDCPOWER_INT32_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE_VAL_ONBOARD_STORAGE\x10\xb2\x08\x12P\nKNIDCPOWER_INT32_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE_VAL_AS_DEFINED\x10\xb3\x08\x12S\nNNIDCPOWER_INT32_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE_VAL_AS_CONFIGURED\x10\xfa\x08\x12N\nINIDCPOWER_INT32_LCR_SOURCE_DELAY_MODE_VAL_LCR_SOURCE_DELAY_MODE_AUTOMATIC\x10\xf8\x08\x12K\nFNIDCPOWER_INT32_LCR_SOURCE_DELAY_MODE_VAL_LCR_SOURCE_DELAY_MODE_MANUAL\x10\xf9\x08\x12\x39\n4NIDCPOWER_INT32_LCR_STIMULUS_FUNCTION_VAL_AC_VOLTAGE\x10\xa7\x08\x12\x39\n4NIDCPOWER_INT32_LCR_STIMULUS_FUNCTION_VAL_AC_CURRENT\x10\xa8\x08\x12I\nDNIDCPOWER_INT32_MEASURE_WHEN_VAL_AUTOMATICALLY_AFTER_SOURCE_COMPLETE\x10\x81\x08\x12/\n*NIDCPOWER_INT32_MEASURE_WHEN_VAL_ON_DEMAND\x10\x82\x08\x12\x38\n3NIDCPOWER_INT32_MEASURE_WHEN_VAL_ON_MEASURE_TRIGGER\x10\x83\x08\x12/\n*NIDCPOWER_INT32_OUTPUT_CAPACITANCE_VAL_LOW\x10\xf2\x07\x12\x30\n+NIDCPOWER_INT32_OUTPUT_CAPACITANCE_VAL_HIGH\x10\xf3\x07\x12\x33\n.NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_DC_VOLTAGE\x10\xee\x07\x12\x33\n.NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_DC_CURRENT\x10\xef\x07\x12\x36\n1NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_PULSE_VOLTAGE\x10\x99\x08\x12\x36\n1NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_PULSE_CURRENT\x10\x9a\x08\x12<\n7NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_CONSTANT_RESISTANCE\x10\x89\t\x12\x37\n2NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_CONSTANT_POWER\x10\x8a\t\x12-\n(NIDCPOWER_INT32_POLARITY_VAL_ACTIVE_HIGH\x10\xfa\x07\x12,\n\'NIDCPOWER_INT32_POLARITY_VAL_ACTIVE_LOW\x10\xfb\x07\x12\x37\n2NIDCPOWER_INT32_POWER_ALLOCATION_MODE_VAL_DISABLED\x10\xa2\x08\x12\x38\n3NIDCPOWER_INT32_POWER_ALLOCATION_MODE_VAL_AUTOMATIC\x10\xa3\x08\x12\x35\n0NIDCPOWER_INT32_POWER_ALLOCATION_MODE_VAL_MANUAL\x10\xa4\x08\x12.\n)NIDCPOWER_INT32_POWER_SOURCE_VAL_INTERNAL\x10\xeb\x07\x12/\n*NIDCPOWER_INT32_POWER_SOURCE_VAL_AUXILIARY\x10\xec\x07\x12/\n*NIDCPOWER_INT32_POWER_SOURCE_VAL_AUTOMATIC\x10\xed\x07\x12\x35\n0NIDCPOWER_INT32_POWER_SOURCE_IN_USE_VAL_INTERNAL\x10\xeb\x07\x12\x36\n1NIDCPOWER_INT32_POWER_SOURCE_IN_USE_VAL_AUXILIARY\x10\xec\x07\x12\x44\n?NIDCPOWER_INT32_SELF_CALIBRATION_PERSISTENCE_VAL_KEEP_IN_MEMORY\x10\x95\x08\x12\x45\n@NIDCPOWER_INT32_SELF_CALIBRATION_PERSISTENCE_VAL_WRITE_TO_EEPROM\x10\x96\x08\x12$\n\x1fNIDCPOWER_INT32_SENSE_VAL_LOCAL\x10\xf0\x07\x12%\n NIDCPOWER_INT32_SENSE_VAL_REMOTE\x10\xf1\x07\x12\x31\n,NIDCPOWER_INT32_SOURCE_MODE_VAL_SINGLE_POINT\x10\xfc\x07\x12-\n(NIDCPOWER_INT32_SOURCE_MODE_VAL_SEQUENCE\x10\xfd\x07\x12\x32\n-NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_NORMAL\x10\x8e\x08\x12\x30\n+NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_FAST\x10\x8f\x08\x12\x30\n+NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_SLOW\x10\x91\x08\x12\x32\n-NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_CUSTOM\x10\x92\x08\x12*\n%NIDCPOWER_INT32_TRIGGER_TYPE_VAL_NONE\x10\xf4\x07\x12\x32\n-NIDCPOWER_INT32_TRIGGER_TYPE_VAL_DIGITAL_EDGE\x10\xf6\x07\x12\x33\n.NIDCPOWER_INT32_TRIGGER_TYPE_VAL_SOFTWARE_EDGE\x10\xf7\x07\x1a\x02\x10\x01*\xb6\x01\n\x1eNiDCPowerReal64AttributeValues\x12 \n\x1cNIDCPOWER_REAL64_UNSPECIFIED\x10\x00\x12\x38\n4NIDCPOWER_REAL64_POWER_LINE_FREQUENCIES_VAL_50_HERTZ\x10\x32\x12\x38\n4NIDCPOWER_REAL64_POWER_LINE_FREQUENCIES_VAL_60_HERTZ\x10<2\x97\x97\x01\n\tNiDCPower\x12w\n\x16InitializeWithChannels\x12-.nidcpower_grpc.InitializeWithChannelsRequest\x1a..nidcpower_grpc.InitializeWithChannelsResponse\x12\x44\n\x05\x43lose\x12\x1c.nidcpower_grpc.CloseRequest\x1a\x1d.nidcpower_grpc.CloseResponse\x12n\n\x13\x43onfigureSourceMode\x12*.nidcpower_grpc.ConfigureSourceModeRequest\x1a+.nidcpower_grpc.ConfigureSourceModeResponse\x12z\n\x17\x43onfigureOutputFunction\x12..nidcpower_grpc.ConfigureOutputFunctionRequest\x1a/.nidcpower_grpc.ConfigureOutputFunctionResponse\x12w\n\x16\x43onfigureOutputEnabled\x12-.nidcpower_grpc.ConfigureOutputEnabledRequest\x1a..nidcpower_grpc.ConfigureOutputEnabledResponse\x12V\n\x0bSetSequence\x12\".nidcpower_grpc.SetSequenceRequest\x1a#.nidcpower_grpc.SetSequenceResponse\x12t\n\x15\x43onfigureVoltageLevel\x12,.nidcpower_grpc.ConfigureVoltageLevelRequest\x1a-.nidcpower_grpc.ConfigureVoltageLevelResponse\x12t\n\x15\x43onfigureCurrentLimit\x12,.nidcpower_grpc.ConfigureCurrentLimitRequest\x1a-.nidcpower_grpc.ConfigureCurrentLimitResponse\x12\x83\x01\n\x1a\x43onfigureVoltageLevelRange\x12\x31.nidcpower_grpc.ConfigureVoltageLevelRangeRequest\x1a\x32.nidcpower_grpc.ConfigureVoltageLevelRangeResponse\x12\x83\x01\n\x1a\x43onfigureCurrentLimitRange\x12\x31.nidcpower_grpc.ConfigureCurrentLimitRangeRequest\x1a\x32.nidcpower_grpc.ConfigureCurrentLimitRangeResponse\x12\x80\x01\n\x19\x43onfigureOutputResistance\x12\x30.nidcpower_grpc.ConfigureOutputResistanceRequest\x1a\x31.nidcpower_grpc.ConfigureOutputResistanceResponse\x12t\n\x15\x43onfigureCurrentLevel\x12,.nidcpower_grpc.ConfigureCurrentLevelRequest\x1a-.nidcpower_grpc.ConfigureCurrentLevelResponse\x12\x83\x01\n\x1a\x43onfigureCurrentLevelRange\x12\x31.nidcpower_grpc.ConfigureCurrentLevelRangeRequest\x1a\x32.nidcpower_grpc.ConfigureCurrentLevelRangeResponse\x12t\n\x15\x43onfigureVoltageLimit\x12,.nidcpower_grpc.ConfigureVoltageLimitRequest\x1a-.nidcpower_grpc.ConfigureVoltageLimitResponse\x12\x83\x01\n\x1a\x43onfigureVoltageLimitRange\x12\x31.nidcpower_grpc.ConfigureVoltageLimitRangeRequest\x1a\x32.nidcpower_grpc.ConfigureVoltageLimitRangeResponse\x12\x83\x01\n\x1a\x43onfigurePulseVoltageLevel\x12\x31.nidcpower_grpc.ConfigurePulseVoltageLevelRequest\x1a\x32.nidcpower_grpc.ConfigurePulseVoltageLevelResponse\x12\x83\x01\n\x1a\x43onfigurePulseCurrentLimit\x12\x31.nidcpower_grpc.ConfigurePulseCurrentLimitRequest\x1a\x32.nidcpower_grpc.ConfigurePulseCurrentLimitResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasVoltageLevel\x12\x35.nidcpower_grpc.ConfigurePulseBiasVoltageLevelRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasVoltageLevelResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasCurrentLimit\x12\x35.nidcpower_grpc.ConfigurePulseBiasCurrentLimitRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasCurrentLimitResponse\x12\x92\x01\n\x1f\x43onfigurePulseVoltageLevelRange\x12\x36.nidcpower_grpc.ConfigurePulseVoltageLevelRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseVoltageLevelRangeResponse\x12\x92\x01\n\x1f\x43onfigurePulseCurrentLimitRange\x12\x36.nidcpower_grpc.ConfigurePulseCurrentLimitRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseCurrentLimitRangeResponse\x12\x83\x01\n\x1a\x43onfigurePulseCurrentLevel\x12\x31.nidcpower_grpc.ConfigurePulseCurrentLevelRequest\x1a\x32.nidcpower_grpc.ConfigurePulseCurrentLevelResponse\x12\x83\x01\n\x1a\x43onfigurePulseVoltageLimit\x12\x31.nidcpower_grpc.ConfigurePulseVoltageLimitRequest\x1a\x32.nidcpower_grpc.ConfigurePulseVoltageLimitResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasCurrentLevel\x12\x35.nidcpower_grpc.ConfigurePulseBiasCurrentLevelRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasCurrentLevelResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasVoltageLimit\x12\x35.nidcpower_grpc.ConfigurePulseBiasVoltageLimitRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasVoltageLimitResponse\x12\x92\x01\n\x1f\x43onfigurePulseCurrentLevelRange\x12\x36.nidcpower_grpc.ConfigurePulseCurrentLevelRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseCurrentLevelRangeResponse\x12\x92\x01\n\x1f\x43onfigurePulseVoltageLimitRange\x12\x36.nidcpower_grpc.ConfigurePulseVoltageLimitRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseVoltageLimitRangeResponse\x12w\n\x16\x43reateAdvancedSequence\x12-.nidcpower_grpc.CreateAdvancedSequenceRequest\x1a..nidcpower_grpc.CreateAdvancedSequenceResponse\x12\x83\x01\n\x1a\x43reateAdvancedSequenceStep\x12\x31.nidcpower_grpc.CreateAdvancedSequenceStepRequest\x1a\x32.nidcpower_grpc.CreateAdvancedSequenceStepResponse\x12w\n\x16\x44\x65leteAdvancedSequence\x12-.nidcpower_grpc.DeleteAdvancedSequenceRequest\x1a..nidcpower_grpc.DeleteAdvancedSequenceResponse\x12t\n\x15\x43onfigureApertureTime\x12,.nidcpower_grpc.ConfigureApertureTimeRequest\x1a-.nidcpower_grpc.ConfigureApertureTimeResponse\x12h\n\x11\x43onfigureAutoZero\x12(.nidcpower_grpc.ConfigureAutoZeroRequest\x1a).nidcpower_grpc.ConfigureAutoZeroResponse\x12\x86\x01\n\x1b\x43onfigurePowerLineFrequency\x12\x32.nidcpower_grpc.ConfigurePowerLineFrequencyRequest\x1a\x33.nidcpower_grpc.ConfigurePowerLineFrequencyResponse\x12_\n\x0e\x43onfigureSense\x12%.nidcpower_grpc.ConfigureSenseRequest\x1a&.nidcpower_grpc.ConfigureSenseResponse\x12J\n\x07Measure\x12\x1e.nidcpower_grpc.MeasureRequest\x1a\x1f.nidcpower_grpc.MeasureResponse\x12\x62\n\x0fMeasureMultiple\x12&.nidcpower_grpc.MeasureMultipleRequest\x1a\'.nidcpower_grpc.MeasureMultipleResponse\x12\\\n\rFetchMultiple\x12$.nidcpower_grpc.FetchMultipleRequest\x1a%.nidcpower_grpc.FetchMultipleResponse\x12k\n\x12MeasureMultipleLCR\x12).nidcpower_grpc.MeasureMultipleLCRRequest\x1a*.nidcpower_grpc.MeasureMultipleLCRResponse\x12\x65\n\x10\x46\x65tchMultipleLCR\x12\'.nidcpower_grpc.FetchMultipleLCRRequest\x1a(.nidcpower_grpc.FetchMultipleLCRResponse\x12h\n\x11QueryInCompliance\x12(.nidcpower_grpc.QueryInComplianceRequest\x1a).nidcpower_grpc.QueryInComplianceResponse\x12\x65\n\x10QueryOutputState\x12\'.nidcpower_grpc.QueryOutputStateRequest\x1a(.nidcpower_grpc.QueryOutputStateResponse\x12\x8c\x01\n\x1dQueryLatchedOutputCutoffState\x12\x34.nidcpower_grpc.QueryLatchedOutputCutoffStateRequest\x1a\x35.nidcpower_grpc.QueryLatchedOutputCutoffStateResponse\x12\x8c\x01\n\x1d\x43learLatchedOutputCutoffState\x12\x34.nidcpower_grpc.ClearLatchedOutputCutoffStateRequest\x1a\x35.nidcpower_grpc.ClearLatchedOutputCutoffStateResponse\x12G\n\x06\x43ommit\x12\x1d.nidcpower_grpc.CommitRequest\x1a\x1e.nidcpower_grpc.CommitResponse\x12M\n\x08Initiate\x12\x1f.nidcpower_grpc.InitiateRequest\x1a .nidcpower_grpc.InitiateResponse\x12\x44\n\x05\x41\x62ort\x12\x1c.nidcpower_grpc.AbortRequest\x1a\x1d.nidcpower_grpc.AbortResponse\x12q\n\x14QueryMaxCurrentLimit\x12+.nidcpower_grpc.QueryMaxCurrentLimitRequest\x1a,.nidcpower_grpc.QueryMaxCurrentLimitResponse\x12q\n\x14QueryMaxVoltageLevel\x12+.nidcpower_grpc.QueryMaxVoltageLevelRequest\x1a,.nidcpower_grpc.QueryMaxVoltageLevelResponse\x12q\n\x14QueryMinCurrentLimit\x12+.nidcpower_grpc.QueryMinCurrentLimitRequest\x1a,.nidcpower_grpc.QueryMinCurrentLimitResponse\x12\x65\n\x10\x43\x61lSelfCalibrate\x12\'.nidcpower_grpc.CalSelfCalibrateRequest\x1a(.nidcpower_grpc.CalSelfCalibrateResponse\x12\x89\x01\n\x1cGetExtCalRecommendedInterval\x12\x33.nidcpower_grpc.GetExtCalRecommendedIntervalRequest\x1a\x34.nidcpower_grpc.GetExtCalRecommendedIntervalResponse\x12}\n\x18GetExtCalLastDateAndTime\x12/.nidcpower_grpc.GetExtCalLastDateAndTimeRequest\x1a\x30.nidcpower_grpc.GetExtCalLastDateAndTimeResponse\x12w\n\x16ReadCurrentTemperature\x12-.nidcpower_grpc.ReadCurrentTemperatureRequest\x1a..nidcpower_grpc.ReadCurrentTemperatureResponse\x12h\n\x11GetExtCalLastTemp\x12(.nidcpower_grpc.GetExtCalLastTempRequest\x1a).nidcpower_grpc.GetExtCalLastTempResponse\x12\x80\x01\n\x19GetSelfCalLastDateAndTime\x12\x30.nidcpower_grpc.GetSelfCalLastDateAndTimeRequest\x1a\x31.nidcpower_grpc.GetSelfCalLastDateAndTimeResponse\x12k\n\x12GetSelfCalLastTemp\x12).nidcpower_grpc.GetSelfCalLastTempRequest\x1a*.nidcpower_grpc.GetSelfCalLastTempResponse\x12\x98\x01\n!GetLCRCompensationLastDateAndTime\x12\x38.nidcpower_grpc.GetLCRCompensationLastDateAndTimeRequest\x1a\x39.nidcpower_grpc.GetLCRCompensationLastDateAndTimeResponse\x12\x95\x01\n ConfigureDigitalEdgeStartTrigger\x12\x37.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerRequest\x1a\x38.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerResponse\x12\x98\x01\n!ConfigureSoftwareEdgeStartTrigger\x12\x38.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerRequest\x1a\x39.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerResponse\x12n\n\x13\x44isableStartTrigger\x12*.nidcpower_grpc.DisableStartTriggerRequest\x1a+.nidcpower_grpc.DisableStartTriggerResponse\x12\xb3\x01\n*ConfigureDigitalEdgeSequenceAdvanceTrigger\x12\x41.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerRequest\x1a\x42.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerResponse\x12\xb6\x01\n+ConfigureSoftwareEdgeSequenceAdvanceTrigger\x12\x42.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerRequest\x1a\x43.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerResponse\x12\x8c\x01\n\x1d\x44isableSequenceAdvanceTrigger\x12\x34.nidcpower_grpc.DisableSequenceAdvanceTriggerRequest\x1a\x35.nidcpower_grpc.DisableSequenceAdvanceTriggerResponse\x12\x98\x01\n!ConfigureDigitalEdgeSourceTrigger\x12\x38.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerRequest\x1a\x39.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerResponse\x12\x9b\x01\n\"ConfigureSoftwareEdgeSourceTrigger\x12\x39.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerRequest\x1a:.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerResponse\x12q\n\x14\x44isableSourceTrigger\x12+.nidcpower_grpc.DisableSourceTriggerRequest\x1a,.nidcpower_grpc.DisableSourceTriggerResponse\x12\x9b\x01\n\"ConfigureDigitalEdgeMeasureTrigger\x12\x39.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerRequest\x1a:.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerResponse\x12\x9e\x01\n#ConfigureSoftwareEdgeMeasureTrigger\x12:.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerRequest\x1a;.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerResponse\x12\x95\x01\n ConfigureDigitalEdgePulseTrigger\x12\x37.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerRequest\x1a\x38.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerResponse\x12\x98\x01\n!ConfigureSoftwareEdgePulseTrigger\x12\x38.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerRequest\x1a\x39.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerResponse\x12n\n\x13\x44isablePulseTrigger\x12*.nidcpower_grpc.DisablePulseTriggerRequest\x1a+.nidcpower_grpc.DisablePulseTriggerResponse\x12Y\n\x0c\x45xportSignal\x12#.nidcpower_grpc.ExportSignalRequest\x1a$.nidcpower_grpc.ExportSignalResponse\x12z\n\x17SendSoftwareEdgeTrigger\x12..nidcpower_grpc.SendSoftwareEdgeTriggerRequest\x1a/.nidcpower_grpc.SendSoftwareEdgeTriggerResponse\x12Y\n\x0cWaitForEvent\x12#.nidcpower_grpc.WaitForEventRequest\x1a$.nidcpower_grpc.WaitForEventResponse\x12J\n\x07\x44isable\x12\x1e.nidcpower_grpc.DisableRequest\x1a\x1f.nidcpower_grpc.DisableResponse\x12\x44\n\x05Reset\x12\x1c.nidcpower_grpc.ResetRequest\x1a\x1d.nidcpower_grpc.ResetResponse\x12V\n\x0bResetDevice\x12\".nidcpower_grpc.ResetDeviceRequest\x1a#.nidcpower_grpc.ResetDeviceResponse\x12M\n\x08SelfTest\x12\x1f.nidcpower_grpc.SelfTestRequest\x1a .nidcpower_grpc.SelfTestResponse\x12\\\n\rRevisionQuery\x12$.nidcpower_grpc.RevisionQueryRequest\x1a%.nidcpower_grpc.RevisionQueryResponse\x12h\n\x11ResetWithDefaults\x12(.nidcpower_grpc.ResetWithDefaultsRequest\x1a).nidcpower_grpc.ResetWithDefaultsResponse\x12_\n\x0eGetChannelName\x12%.nidcpower_grpc.GetChannelNameRequest\x1a&.nidcpower_grpc.GetChannelNameResponse\x12}\n\x18GetChannelNameFromString\x12/.nidcpower_grpc.GetChannelNameFromStringRequest\x1a\x30.nidcpower_grpc.GetChannelNameFromStringResponse\x12t\n\x15GetNextCoercionRecord\x12,.nidcpower_grpc.GetNextCoercionRecordRequest\x1a-.nidcpower_grpc.GetNextCoercionRecordResponse\x12}\n\x18\x43learInterchangeWarnings\x12/.nidcpower_grpc.ClearInterchangeWarningsRequest\x1a\x30.nidcpower_grpc.ClearInterchangeWarningsResponse\x12t\n\x15ResetInterchangeCheck\x12,.nidcpower_grpc.ResetInterchangeCheckRequest\x1a-.nidcpower_grpc.ResetInterchangeCheckResponse\x12\x80\x01\n\x19GetNextInterchangeWarning\x12\x30.nidcpower_grpc.GetNextInterchangeWarningRequest\x1a\x31.nidcpower_grpc.GetNextInterchangeWarningResponse\x12M\n\x08GetError\x12\x1f.nidcpower_grpc.GetErrorRequest\x1a .nidcpower_grpc.GetErrorResponse\x12S\n\nClearError\x12!.nidcpower_grpc.ClearErrorRequest\x1a\".nidcpower_grpc.ClearErrorResponse\x12Y\n\x0c\x45rrorMessage\x12#.nidcpower_grpc.ErrorMessageRequest\x1a$.nidcpower_grpc.ErrorMessageResponse\x12n\n\x13SetAttributeViInt32\x12*.nidcpower_grpc.SetAttributeViInt32Request\x1a+.nidcpower_grpc.SetAttributeViInt32Response\x12n\n\x13SetAttributeViInt64\x12*.nidcpower_grpc.SetAttributeViInt64Request\x1a+.nidcpower_grpc.SetAttributeViInt64Response\x12q\n\x14SetAttributeViReal64\x12+.nidcpower_grpc.SetAttributeViReal64Request\x1a,.nidcpower_grpc.SetAttributeViReal64Response\x12q\n\x14SetAttributeViString\x12+.nidcpower_grpc.SetAttributeViStringRequest\x1a,.nidcpower_grpc.SetAttributeViStringResponse\x12t\n\x15SetAttributeViSession\x12,.nidcpower_grpc.SetAttributeViSessionRequest\x1a-.nidcpower_grpc.SetAttributeViSessionResponse\x12t\n\x15SetAttributeViBoolean\x12,.nidcpower_grpc.SetAttributeViBooleanRequest\x1a-.nidcpower_grpc.SetAttributeViBooleanResponse\x12n\n\x13GetAttributeViInt32\x12*.nidcpower_grpc.GetAttributeViInt32Request\x1a+.nidcpower_grpc.GetAttributeViInt32Response\x12n\n\x13GetAttributeViInt64\x12*.nidcpower_grpc.GetAttributeViInt64Request\x1a+.nidcpower_grpc.GetAttributeViInt64Response\x12q\n\x14GetAttributeViReal64\x12+.nidcpower_grpc.GetAttributeViReal64Request\x1a,.nidcpower_grpc.GetAttributeViReal64Response\x12q\n\x14GetAttributeViString\x12+.nidcpower_grpc.GetAttributeViStringRequest\x1a,.nidcpower_grpc.GetAttributeViStringResponse\x12t\n\x15GetAttributeViSession\x12,.nidcpower_grpc.GetAttributeViSessionRequest\x1a-.nidcpower_grpc.GetAttributeViSessionResponse\x12t\n\x15GetAttributeViBoolean\x12,.nidcpower_grpc.GetAttributeViBooleanRequest\x1a-.nidcpower_grpc.GetAttributeViBooleanResponse\x12\x95\x01\n ImportAttributeConfigurationFile\x12\x37.nidcpower_grpc.ImportAttributeConfigurationFileRequest\x1a\x38.nidcpower_grpc.ImportAttributeConfigurationFileResponse\x12\x95\x01\n ExportAttributeConfigurationFile\x12\x37.nidcpower_grpc.ExportAttributeConfigurationFileRequest\x1a\x38.nidcpower_grpc.ExportAttributeConfigurationFileResponse\x12\x9b\x01\n\"ImportAttributeConfigurationBuffer\x12\x39.nidcpower_grpc.ImportAttributeConfigurationBufferRequest\x1a:.nidcpower_grpc.ImportAttributeConfigurationBufferResponse\x12\x9b\x01\n\"ExportAttributeConfigurationBuffer\x12\x39.nidcpower_grpc.ExportAttributeConfigurationBufferRequest\x1a:.nidcpower_grpc.ExportAttributeConfigurationBufferResponse\x12\x83\x01\n\x1aPerformLCROpenCompensation\x12\x31.nidcpower_grpc.PerformLCROpenCompensationRequest\x1a\x32.nidcpower_grpc.PerformLCROpenCompensationResponse\x12\x86\x01\n\x1bPerformLCRShortCompensation\x12\x32.nidcpower_grpc.PerformLCRShortCompensationRequest\x1a\x33.nidcpower_grpc.PerformLCRShortCompensationResponse\x12\x83\x01\n\x1aPerformLCRLoadCompensation\x12\x31.nidcpower_grpc.PerformLCRLoadCompensationRequest\x1a\x32.nidcpower_grpc.PerformLCRLoadCompensationResponse\x12}\n\x18\x43onfigureLCRCompensation\x12/.nidcpower_grpc.ConfigureLCRCompensationRequest\x1a\x30.nidcpower_grpc.ConfigureLCRCompensationResponse\x12\xa4\x01\n%PerformLCROpenCustomCableCompensation\x12<.nidcpower_grpc.PerformLCROpenCustomCableCompensationRequest\x1a=.nidcpower_grpc.PerformLCROpenCustomCableCompensationResponse\x12\xa7\x01\n&PerformLCRShortCustomCableCompensation\x12=.nidcpower_grpc.PerformLCRShortCustomCableCompensationRequest\x1a>.nidcpower_grpc.PerformLCRShortCustomCableCompensationResponse\x12w\n\x16GetLCRCompensationData\x12-.nidcpower_grpc.GetLCRCompensationDataRequest\x1a..nidcpower_grpc.GetLCRCompensationDataResponse\x12\x98\x01\n!InitializeWithIndependentChannels\x12\x38.nidcpower_grpc.InitializeWithIndependentChannelsRequest\x1a\x39.nidcpower_grpc.InitializeWithIndependentChannelsResponse\x12\x92\x01\n\x1f\x43onfigureSourceModeWithChannels\x12\x36.nidcpower_grpc.ConfigureSourceModeWithChannelsRequest\x1a\x37.nidcpower_grpc.ConfigureSourceModeWithChannelsResponse\x12\x9b\x01\n\"CreateAdvancedSequenceWithChannels\x12\x39.nidcpower_grpc.CreateAdvancedSequenceWithChannelsRequest\x1a:.nidcpower_grpc.CreateAdvancedSequenceWithChannelsResponse\x12\xa7\x01\n&CreateAdvancedSequenceStepWithChannels\x12=.nidcpower_grpc.CreateAdvancedSequenceStepWithChannelsRequest\x1a>.nidcpower_grpc.CreateAdvancedSequenceStepWithChannelsResponse\x12\xb9\x01\n,CreateAdvancedSequenceCommitStepWithChannels\x12\x43.nidcpower_grpc.CreateAdvancedSequenceCommitStepWithChannelsRequest\x1a\x44.nidcpower_grpc.CreateAdvancedSequenceCommitStepWithChannelsResponse\x12\x9b\x01\n\"DeleteAdvancedSequenceWithChannels\x12\x39.nidcpower_grpc.DeleteAdvancedSequenceWithChannelsRequest\x1a:.nidcpower_grpc.DeleteAdvancedSequenceWithChannelsResponse\x12k\n\x12\x43ommitWithChannels\x12).nidcpower_grpc.CommitWithChannelsRequest\x1a*.nidcpower_grpc.CommitWithChannelsResponse\x12q\n\x14InitiateWithChannels\x12+.nidcpower_grpc.InitiateWithChannelsRequest\x1a,.nidcpower_grpc.InitiateWithChannelsResponse\x12h\n\x11\x41\x62ortWithChannels\x12(.nidcpower_grpc.AbortWithChannelsRequest\x1a).nidcpower_grpc.AbortWithChannelsResponse\x12\xb9\x01\n,ConfigureDigitalEdgeStartTriggerWithChannels\x12\x43.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerWithChannelsRequest\x1a\x44.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerWithChannelsResponse\x12\xbc\x01\n-ConfigureSoftwareEdgeStartTriggerWithChannels\x12\x44.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerWithChannelsRequest\x1a\x45.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerWithChannelsResponse\x12\x92\x01\n\x1f\x44isableStartTriggerWithChannels\x12\x36.nidcpower_grpc.DisableStartTriggerWithChannelsRequest\x1a\x37.nidcpower_grpc.DisableStartTriggerWithChannelsResponse\x12\xd7\x01\n6ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannels\x12M.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsRequest\x1aN.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\xda\x01\n7ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannels\x12N.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsRequest\x1aO.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\xb0\x01\n)DisableSequenceAdvanceTriggerWithChannels\x12@.nidcpower_grpc.DisableSequenceAdvanceTriggerWithChannelsRequest\x1a\x41.nidcpower_grpc.DisableSequenceAdvanceTriggerWithChannelsResponse\x12\xbc\x01\n-ConfigureDigitalEdgeSourceTriggerWithChannels\x12\x44.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerWithChannelsRequest\x1a\x45.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerWithChannelsResponse\x12\xbf\x01\n.ConfigureSoftwareEdgeSourceTriggerWithChannels\x12\x45.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerWithChannelsRequest\x1a\x46.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerWithChannelsResponse\x12\x95\x01\n DisableSourceTriggerWithChannels\x12\x37.nidcpower_grpc.DisableSourceTriggerWithChannelsRequest\x1a\x38.nidcpower_grpc.DisableSourceTriggerWithChannelsResponse\x12\xbf\x01\n.ConfigureDigitalEdgeMeasureTriggerWithChannels\x12\x45.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerWithChannelsRequest\x1a\x46.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerWithChannelsResponse\x12\xc2\x01\n/ConfigureSoftwareEdgeMeasureTriggerWithChannels\x12\x46.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerWithChannelsRequest\x1aG.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerWithChannelsResponse\x12\xb9\x01\n,ConfigureDigitalEdgePulseTriggerWithChannels\x12\x43.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerWithChannelsRequest\x1a\x44.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerWithChannelsResponse\x12\xbc\x01\n-ConfigureSoftwareEdgePulseTriggerWithChannels\x12\x44.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerWithChannelsRequest\x1a\x45.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerWithChannelsResponse\x12\x92\x01\n\x1f\x44isablePulseTriggerWithChannels\x12\x36.nidcpower_grpc.DisablePulseTriggerWithChannelsRequest\x1a\x37.nidcpower_grpc.DisablePulseTriggerWithChannelsResponse\x12\xc2\x01\n/ConfigureDigitalEdgeShutdownTriggerWithChannels\x12\x46.nidcpower_grpc.ConfigureDigitalEdgeShutdownTriggerWithChannelsRequest\x1aG.nidcpower_grpc.ConfigureDigitalEdgeShutdownTriggerWithChannelsResponse\x12\xc5\x01\n0ConfigureSoftwareEdgeShutdownTriggerWithChannels\x12G.nidcpower_grpc.ConfigureSoftwareEdgeShutdownTriggerWithChannelsRequest\x1aH.nidcpower_grpc.ConfigureSoftwareEdgeShutdownTriggerWithChannelsResponse\x12\x9b\x01\n\"DisableShutdownTriggerWithChannels\x12\x39.nidcpower_grpc.DisableShutdownTriggerWithChannelsRequest\x1a:.nidcpower_grpc.DisableShutdownTriggerWithChannelsResponse\x12}\n\x18\x45xportSignalWithChannels\x12/.nidcpower_grpc.ExportSignalWithChannelsRequest\x1a\x30.nidcpower_grpc.ExportSignalWithChannelsResponse\x12\x9e\x01\n#SendSoftwareEdgeTriggerWithChannels\x12:.nidcpower_grpc.SendSoftwareEdgeTriggerWithChannelsRequest\x1a;.nidcpower_grpc.SendSoftwareEdgeTriggerWithChannelsResponse\x12}\n\x18WaitForEventWithChannels\x12/.nidcpower_grpc.WaitForEventWithChannelsRequest\x1a\x30.nidcpower_grpc.WaitForEventWithChannelsResponse\x12h\n\x11ResetWithChannels\x12(.nidcpower_grpc.ResetWithChannelsRequest\x1a).nidcpower_grpc.ResetWithChannelsResponse\x12z\n\x17InvalidateAllAttributes\x12..nidcpower_grpc.InvalidateAllAttributesRequest\x1a/.nidcpower_grpc.InvalidateAllAttributesResponse\x12Y\n\x0c\x43onfigureOvp\x12#.nidcpower_grpc.ConfigureOvpRequest\x1a$.nidcpower_grpc.ConfigureOvpResponse\x12S\n\nErrorQuery\x12!.nidcpower_grpc.ErrorQueryRequest\x1a\".nidcpower_grpc.ErrorQueryResponse\x12\x98\x01\n!GetLCRCustomCableCompensationData\x12\x38.nidcpower_grpc.GetLCRCustomCableCompensationDataRequest\x1a\x39.nidcpower_grpc.GetLCRCustomCableCompensationDataResponse\x12\x9e\x01\n#ConfigureLCRCustomCableCompensation\x12:.nidcpower_grpc.ConfigureLCRCustomCableCompensationRequest\x1a;.nidcpower_grpc.ConfigureLCRCustomCableCompensationResponseBE\n\x13\x63om.ni.grpc.dcpowerB\tNiDCPowerP\x01\xaa\x02 NationalInstruments.Grpc.DCPowerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nidcpower_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.ni.grpc.dcpowerB\tNiDCPowerP\001\252\002 NationalInstruments.Grpc.DCPower'
  _NIDCPOWERINT32ATTRIBUTEVALUES._options = None
  _NIDCPOWERINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._options = None
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE.fields_by_name['error_message']._options = None
  _INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _globals['_NIDCPOWERATTRIBUTE']._serialized_start=28538
  _globals['_NIDCPOWERATTRIBUTE']._serialized_end=41532
  _globals['_CURRENTLIMITBEHAVIOR']._serialized_start=41535
  _globals['_CURRENTLIMITBEHAVIOR']._serialized_end=41671
  _globals['_OUTPUTSTATES']._serialized_start=41674
  _globals['_OUTPUTSTATES']._serialized_end=42011
  _globals['_MEASUREMENTTYPES']._serialized_start=42013
  _globals['_MEASUREMENTTYPES']._serialized_end=42137
  _globals['_OUTPUTFUNCTION']._serialized_start=42140
  _globals['_OUTPUTFUNCTION']._serialized_end=42490
  _globals['_SENSE']._serialized_start=42492
  _globals['_SENSE']._serialized_end=42587
  _globals['_DIGITALEDGE']._serialized_start=42589
  _globals['_DIGITALEDGE']._serialized_end=42713
  _globals['_SOURCEMODE']._serialized_start=42715
  _globals['_SOURCEMODE']._serialized_end=42842
  _globals['_AUTOZERO']._serialized_start=42844
  _globals['_AUTOZERO']._serialized_end=42954
  _globals['_POWERLINEFREQUENCIES']._serialized_start=42957
  _globals['_POWERLINEFREQUENCIES']._serialized_end=43121
  _globals['_APERTURETIMEUNITS']._serialized_start=43124
  _globals['_APERTURETIMEUNITS']._serialized_end=43286
  _globals['_EXPORTSIGNAL']._serialized_start=43289
  _globals['_EXPORTSIGNAL']._serialized_end=44000
  _globals['_OUTPUTCUTOFFREASON']._serialized_start=44003
  _globals['_OUTPUTCUTOFFREASON']._serialized_end=45284
  _globals['_LCRCOMPENSATIONTYPE']._serialized_start=45287
  _globals['_LCRCOMPENSATIONTYPE']._serialized_end=45675
  _globals['_EVENT']._serialized_start=45678
  _globals['_EVENT']._serialized_end=45985
  _globals['_SENDSOFTWAREEDGETRIGGERTYPE']._serialized_start=45988
  _globals['_SENDSOFTWAREEDGETRIGGERTYPE']._serialized_end=46431
  _globals['_NIDCPOWERINT32ATTRIBUTEVALUES']._serialized_start=46434
  _globals['_NIDCPOWERINT32ATTRIBUTEVALUES']._serialized_end=52720
  _globals['_NIDCPOWERREAL64ATTRIBUTEVALUES']._serialized_start=52723
  _globals['_NIDCPOWERREAL64ATTRIBUTEVALUES']._serialized_end=52905
  _globals['_NILCRMEASUREMENT']._serialized_start=67
  _globals['_NILCRMEASUREMENT']._serialized_end=597
  _globals['_NILCRLOADCOMPENSATIONSPOT']._serialized_start=600
  _globals['_NILCRLOADCOMPENSATIONSPOT']._serialized_end=730
  _globals['_INITIALIZEWITHCHANNELSREQUEST']._serialized_start=733
  _globals['_INITIALIZEWITHCHANNELSREQUEST']._serialized_end=944
  _globals['_INITIALIZEWITHCHANNELSRESPONSE']._serialized_start=947
  _globals['_INITIALIZEWITHCHANNELSRESPONSE']._serialized_end=1091
  _globals['_CLOSEREQUEST']._serialized_start=1093
  _globals['_CLOSEREQUEST']._serialized_end=1143
  _globals['_CLOSERESPONSE']._serialized_start=1145
  _globals['_CLOSERESPONSE']._serialized_end=1176
  _globals['_CONFIGURESOURCEMODEREQUEST']._serialized_start=1179
  _globals['_CONFIGURESOURCEMODEREQUEST']._serialized_end=1341
  _globals['_CONFIGURESOURCEMODERESPONSE']._serialized_start=1343
  _globals['_CONFIGURESOURCEMODERESPONSE']._serialized_end=1388
  _globals['_CONFIGUREOUTPUTFUNCTIONREQUEST']._serialized_start=1391
  _globals['_CONFIGUREOUTPUTFUNCTIONREQUEST']._serialized_end=1574
  _globals['_CONFIGUREOUTPUTFUNCTIONRESPONSE']._serialized_start=1576
  _globals['_CONFIGUREOUTPUTFUNCTIONRESPONSE']._serialized_end=1625
  _globals['_CONFIGUREOUTPUTENABLEDREQUEST']._serialized_start=1627
  _globals['_CONFIGUREOUTPUTENABLEDREQUEST']._serialized_end=1733
  _globals['_CONFIGUREOUTPUTENABLEDRESPONSE']._serialized_start=1735
  _globals['_CONFIGUREOUTPUTENABLEDRESPONSE']._serialized_end=1783
  _globals['_SETSEQUENCEREQUEST']._serialized_start=1785
  _globals['_SETSEQUENCEREQUEST']._serialized_end=1902
  _globals['_SETSEQUENCERESPONSE']._serialized_start=1904
  _globals['_SETSEQUENCERESPONSE']._serialized_end=1941
  _globals['_CONFIGUREVOLTAGELEVELREQUEST']._serialized_start=1943
  _globals['_CONFIGUREVOLTAGELEVELREQUEST']._serialized_end=2046
  _globals['_CONFIGUREVOLTAGELEVELRESPONSE']._serialized_start=2048
  _globals['_CONFIGUREVOLTAGELEVELRESPONSE']._serialized_end=2095
  _globals['_CONFIGURECURRENTLIMITREQUEST']._serialized_start=2098
  _globals['_CONFIGURECURRENTLIMITREQUEST']._serialized_end=2300
  _globals['_CONFIGURECURRENTLIMITRESPONSE']._serialized_start=2302
  _globals['_CONFIGURECURRENTLIMITRESPONSE']._serialized_end=2349
  _globals['_CONFIGUREVOLTAGELEVELRANGEREQUEST']._serialized_start=2351
  _globals['_CONFIGUREVOLTAGELEVELRANGEREQUEST']._serialized_end=2459
  _globals['_CONFIGUREVOLTAGELEVELRANGERESPONSE']._serialized_start=2461
  _globals['_CONFIGUREVOLTAGELEVELRANGERESPONSE']._serialized_end=2513
  _globals['_CONFIGURECURRENTLIMITRANGEREQUEST']._serialized_start=2515
  _globals['_CONFIGURECURRENTLIMITRANGEREQUEST']._serialized_end=2623
  _globals['_CONFIGURECURRENTLIMITRANGERESPONSE']._serialized_start=2625
  _globals['_CONFIGURECURRENTLIMITRANGERESPONSE']._serialized_end=2677
  _globals['_CONFIGUREOUTPUTRESISTANCEREQUEST']._serialized_start=2679
  _globals['_CONFIGUREOUTPUTRESISTANCEREQUEST']._serialized_end=2791
  _globals['_CONFIGUREOUTPUTRESISTANCERESPONSE']._serialized_start=2793
  _globals['_CONFIGUREOUTPUTRESISTANCERESPONSE']._serialized_end=2844
  _globals['_CONFIGURECURRENTLEVELREQUEST']._serialized_start=2846
  _globals['_CONFIGURECURRENTLEVELREQUEST']._serialized_end=2949
  _globals['_CONFIGURECURRENTLEVELRESPONSE']._serialized_start=2951
  _globals['_CONFIGURECURRENTLEVELRESPONSE']._serialized_end=2998
  _globals['_CONFIGURECURRENTLEVELRANGEREQUEST']._serialized_start=3000
  _globals['_CONFIGURECURRENTLEVELRANGEREQUEST']._serialized_end=3108
  _globals['_CONFIGURECURRENTLEVELRANGERESPONSE']._serialized_start=3110
  _globals['_CONFIGURECURRENTLEVELRANGERESPONSE']._serialized_end=3162
  _globals['_CONFIGUREVOLTAGELIMITREQUEST']._serialized_start=3164
  _globals['_CONFIGUREVOLTAGELIMITREQUEST']._serialized_end=3267
  _globals['_CONFIGUREVOLTAGELIMITRESPONSE']._serialized_start=3269
  _globals['_CONFIGUREVOLTAGELIMITRESPONSE']._serialized_end=3316
  _globals['_CONFIGUREVOLTAGELIMITRANGEREQUEST']._serialized_start=3318
  _globals['_CONFIGUREVOLTAGELIMITRANGEREQUEST']._serialized_end=3426
  _globals['_CONFIGUREVOLTAGELIMITRANGERESPONSE']._serialized_start=3428
  _globals['_CONFIGUREVOLTAGELIMITRANGERESPONSE']._serialized_end=3480
  _globals['_CONFIGUREPULSEVOLTAGELEVELREQUEST']._serialized_start=3482
  _globals['_CONFIGUREPULSEVOLTAGELEVELREQUEST']._serialized_end=3590
  _globals['_CONFIGUREPULSEVOLTAGELEVELRESPONSE']._serialized_start=3592
  _globals['_CONFIGUREPULSEVOLTAGELEVELRESPONSE']._serialized_end=3644
  _globals['_CONFIGUREPULSECURRENTLIMITREQUEST']._serialized_start=3646
  _globals['_CONFIGUREPULSECURRENTLIMITREQUEST']._serialized_end=3754
  _globals['_CONFIGUREPULSECURRENTLIMITRESPONSE']._serialized_start=3756
  _globals['_CONFIGUREPULSECURRENTLIMITRESPONSE']._serialized_end=3808
  _globals['_CONFIGUREPULSEBIASVOLTAGELEVELREQUEST']._serialized_start=3810
  _globals['_CONFIGUREPULSEBIASVOLTAGELEVELREQUEST']._serialized_end=3922
  _globals['_CONFIGUREPULSEBIASVOLTAGELEVELRESPONSE']._serialized_start=3924
  _globals['_CONFIGUREPULSEBIASVOLTAGELEVELRESPONSE']._serialized_end=3980
  _globals['_CONFIGUREPULSEBIASCURRENTLIMITREQUEST']._serialized_start=3982
  _globals['_CONFIGUREPULSEBIASCURRENTLIMITREQUEST']._serialized_end=4094
  _globals['_CONFIGUREPULSEBIASCURRENTLIMITRESPONSE']._serialized_start=4096
  _globals['_CONFIGUREPULSEBIASCURRENTLIMITRESPONSE']._serialized_end=4152
  _globals['_CONFIGUREPULSEVOLTAGELEVELRANGEREQUEST']._serialized_start=4154
  _globals['_CONFIGUREPULSEVOLTAGELEVELRANGEREQUEST']._serialized_end=4267
  _globals['_CONFIGUREPULSEVOLTAGELEVELRANGERESPONSE']._serialized_start=4269
  _globals['_CONFIGUREPULSEVOLTAGELEVELRANGERESPONSE']._serialized_end=4326
  _globals['_CONFIGUREPULSECURRENTLIMITRANGEREQUEST']._serialized_start=4328
  _globals['_CONFIGUREPULSECURRENTLIMITRANGEREQUEST']._serialized_end=4441
  _globals['_CONFIGUREPULSECURRENTLIMITRANGERESPONSE']._serialized_start=4443
  _globals['_CONFIGUREPULSECURRENTLIMITRANGERESPONSE']._serialized_end=4500
  _globals['_CONFIGUREPULSECURRENTLEVELREQUEST']._serialized_start=4502
  _globals['_CONFIGUREPULSECURRENTLEVELREQUEST']._serialized_end=4610
  _globals['_CONFIGUREPULSECURRENTLEVELRESPONSE']._serialized_start=4612
  _globals['_CONFIGUREPULSECURRENTLEVELRESPONSE']._serialized_end=4664
  _globals['_CONFIGUREPULSEVOLTAGELIMITREQUEST']._serialized_start=4666
  _globals['_CONFIGUREPULSEVOLTAGELIMITREQUEST']._serialized_end=4774
  _globals['_CONFIGUREPULSEVOLTAGELIMITRESPONSE']._serialized_start=4776
  _globals['_CONFIGUREPULSEVOLTAGELIMITRESPONSE']._serialized_end=4828
  _globals['_CONFIGUREPULSEBIASCURRENTLEVELREQUEST']._serialized_start=4830
  _globals['_CONFIGUREPULSEBIASCURRENTLEVELREQUEST']._serialized_end=4942
  _globals['_CONFIGUREPULSEBIASCURRENTLEVELRESPONSE']._serialized_start=4944
  _globals['_CONFIGUREPULSEBIASCURRENTLEVELRESPONSE']._serialized_end=5000
  _globals['_CONFIGUREPULSEBIASVOLTAGELIMITREQUEST']._serialized_start=5002
  _globals['_CONFIGUREPULSEBIASVOLTAGELIMITREQUEST']._serialized_end=5114
  _globals['_CONFIGUREPULSEBIASVOLTAGELIMITRESPONSE']._serialized_start=5116
  _globals['_CONFIGUREPULSEBIASVOLTAGELIMITRESPONSE']._serialized_end=5172
  _globals['_CONFIGUREPULSECURRENTLEVELRANGEREQUEST']._serialized_start=5174
  _globals['_CONFIGUREPULSECURRENTLEVELRANGEREQUEST']._serialized_end=5287
  _globals['_CONFIGUREPULSECURRENTLEVELRANGERESPONSE']._serialized_start=5289
  _globals['_CONFIGUREPULSECURRENTLEVELRANGERESPONSE']._serialized_end=5346
  _globals['_CONFIGUREPULSEVOLTAGELIMITRANGEREQUEST']._serialized_start=5348
  _globals['_CONFIGUREPULSEVOLTAGELIMITRANGEREQUEST']._serialized_end=5461
  _globals['_CONFIGUREPULSEVOLTAGELIMITRANGERESPONSE']._serialized_start=5463
  _globals['_CONFIGUREPULSEVOLTAGELIMITRANGERESPONSE']._serialized_end=5520
  _globals['_CREATEADVANCEDSEQUENCEREQUEST']._serialized_start=5523
  _globals['_CREATEADVANCEDSEQUENCEREQUEST']._serialized_end=5668
  _globals['_CREATEADVANCEDSEQUENCERESPONSE']._serialized_start=5670
  _globals['_CREATEADVANCEDSEQUENCERESPONSE']._serialized_end=5718
  _globals['_CREATEADVANCEDSEQUENCESTEPREQUEST']._serialized_start=5720
  _globals['_CREATEADVANCEDSEQUENCESTEPREQUEST']._serialized_end=5819
  _globals['_CREATEADVANCEDSEQUENCESTEPRESPONSE']._serialized_start=5821
  _globals['_CREATEADVANCEDSEQUENCESTEPRESPONSE']._serialized_end=5873
  _globals['_DELETEADVANCEDSEQUENCEREQUEST']._serialized_start=5875
  _globals['_DELETEADVANCEDSEQUENCEREQUEST']._serialized_end=5965
  _globals['_DELETEADVANCEDSEQUENCERESPONSE']._serialized_start=5967
  _globals['_DELETEADVANCEDSEQUENCERESPONSE']._serialized_end=6015
  _globals['_CONFIGUREAPERTURETIMEREQUEST']._serialized_start=6018
  _globals['_CONFIGUREAPERTURETIMEREQUEST']._serialized_end=6216
  _globals['_CONFIGUREAPERTURETIMERESPONSE']._serialized_start=6218
  _globals['_CONFIGUREAPERTURETIMERESPONSE']._serialized_end=6265
  _globals['_CONFIGUREAUTOZEROREQUEST']._serialized_start=6268
  _globals['_CONFIGUREAUTOZEROREQUEST']._serialized_end=6442
  _globals['_CONFIGUREAUTOZERORESPONSE']._serialized_start=6444
  _globals['_CONFIGUREAUTOZERORESPONSE']._serialized_end=6487
  _globals['_CONFIGUREPOWERLINEFREQUENCYREQUEST']._serialized_start=6490
  _globals['_CONFIGUREPOWERLINEFREQUENCYREQUEST']._serialized_end=6694
  _globals['_CONFIGUREPOWERLINEFREQUENCYRESPONSE']._serialized_start=6696
  _globals['_CONFIGUREPOWERLINEFREQUENCYRESPONSE']._serialized_end=6749
  _globals['_CONFIGURESENSEREQUEST']._serialized_start=6752
  _globals['_CONFIGURESENSEREQUEST']._serialized_end=6908
  _globals['_CONFIGURESENSERESPONSE']._serialized_start=6910
  _globals['_CONFIGURESENSERESPONSE']._serialized_end=6950
  _globals['_MEASUREREQUEST']._serialized_start=6953
  _globals['_MEASUREREQUEST']._serialized_end=7146
  _globals['_MEASURERESPONSE']._serialized_start=7148
  _globals['_MEASURERESPONSE']._serialized_end=7202
  _globals['_MEASUREMULTIPLEREQUEST']._serialized_start=7204
  _globals['_MEASUREMULTIPLEREQUEST']._serialized_end=7286
  _globals['_MEASUREMULTIPLERESPONSE']._serialized_start=7288
  _globals['_MEASUREMULTIPLERESPONSE']._serialized_end=7389
  _globals['_FETCHMULTIPLEREQUEST']._serialized_start=7391
  _globals['_FETCHMULTIPLEREQUEST']._serialized_end=7503
  _globals['_FETCHMULTIPLERESPONSE']._serialized_start=7506
  _globals['_FETCHMULTIPLERESPONSE']._serialized_end=7650
  _globals['_MEASUREMULTIPLELCRREQUEST']._serialized_start=7652
  _globals['_MEASUREMULTIPLELCRREQUEST']._serialized_end=7737
  _globals['_MEASUREMULTIPLELCRRESPONSE']._serialized_start=7739
  _globals['_MEASUREMULTIPLELCRRESPONSE']._serialized_end=7839
  _globals['_FETCHMULTIPLELCRREQUEST']._serialized_start=7841
  _globals['_FETCHMULTIPLELCRREQUEST']._serialized_end=7956
  _globals['_FETCHMULTIPLELCRRESPONSE']._serialized_start=7958
  _globals['_FETCHMULTIPLELCRRESPONSE']._serialized_end=8078
  _globals['_QUERYINCOMPLIANCEREQUEST']._serialized_start=8080
  _globals['_QUERYINCOMPLIANCEREQUEST']._serialized_end=8164
  _globals['_QUERYINCOMPLIANCERESPONSE']._serialized_start=8166
  _globals['_QUERYINCOMPLIANCERESPONSE']._serialized_end=8232
  _globals['_QUERYOUTPUTSTATEREQUEST']._serialized_start=8235
  _globals['_QUERYOUTPUTSTATEREQUEST']._serialized_end=8421
  _globals['_QUERYOUTPUTSTATERESPONSE']._serialized_start=8423
  _globals['_QUERYOUTPUTSTATERESPONSE']._serialized_end=8483
  _globals['_QUERYLATCHEDOUTPUTCUTOFFSTATEREQUEST']._serialized_start=8486
  _globals['_QUERYLATCHEDOUTPUTCUTOFFSTATEREQUEST']._serialized_end=8715
  _globals['_QUERYLATCHEDOUTPUTCUTOFFSTATERESPONSE']._serialized_start=8717
  _globals['_QUERYLATCHEDOUTPUTCUTOFFSTATERESPONSE']._serialized_end=8801
  _globals['_CLEARLATCHEDOUTPUTCUTOFFSTATEREQUEST']._serialized_start=8804
  _globals['_CLEARLATCHEDOUTPUTCUTOFFSTATEREQUEST']._serialized_end=9033
  _globals['_CLEARLATCHEDOUTPUTCUTOFFSTATERESPONSE']._serialized_start=9035
  _globals['_CLEARLATCHEDOUTPUTCUTOFFSTATERESPONSE']._serialized_end=9090
  _globals['_COMMITREQUEST']._serialized_start=9092
  _globals['_COMMITREQUEST']._serialized_end=9143
  _globals['_COMMITRESPONSE']._serialized_start=9145
  _globals['_COMMITRESPONSE']._serialized_end=9177
  _globals['_INITIATEREQUEST']._serialized_start=9179
  _globals['_INITIATEREQUEST']._serialized_end=9232
  _globals['_INITIATERESPONSE']._serialized_start=9234
  _globals['_INITIATERESPONSE']._serialized_end=9268
  _globals['_ABORTREQUEST']._serialized_start=9270
  _globals['_ABORTREQUEST']._serialized_end=9320
  _globals['_ABORTRESPONSE']._serialized_start=9322
  _globals['_ABORTRESPONSE']._serialized_end=9353
  _globals['_QUERYMAXCURRENTLIMITREQUEST']._serialized_start=9355
  _globals['_QUERYMAXCURRENTLIMITREQUEST']._serialized_end=9465
  _globals['_QUERYMAXCURRENTLIMITRESPONSE']._serialized_start=9467
  _globals['_QUERYMAXCURRENTLIMITRESPONSE']._serialized_end=9540
  _globals['_QUERYMAXVOLTAGELEVELREQUEST']._serialized_start=9542
  _globals['_QUERYMAXVOLTAGELEVELREQUEST']._serialized_end=9652
  _globals['_QUERYMAXVOLTAGELEVELRESPONSE']._serialized_start=9654
  _globals['_QUERYMAXVOLTAGELEVELRESPONSE']._serialized_end=9727
  _globals['_QUERYMINCURRENTLIMITREQUEST']._serialized_start=9729
  _globals['_QUERYMINCURRENTLIMITREQUEST']._serialized_end=9839
  _globals['_QUERYMINCURRENTLIMITRESPONSE']._serialized_start=9841
  _globals['_QUERYMINCURRENTLIMITRESPONSE']._serialized_end=9914
  _globals['_CALSELFCALIBRATEREQUEST']._serialized_start=9916
  _globals['_CALSELFCALIBRATEREQUEST']._serialized_end=9999
  _globals['_CALSELFCALIBRATERESPONSE']._serialized_start=10001
  _globals['_CALSELFCALIBRATERESPONSE']._serialized_end=10043
  _globals['_GETEXTCALRECOMMENDEDINTERVALREQUEST']._serialized_start=10045
  _globals['_GETEXTCALRECOMMENDEDINTERVALREQUEST']._serialized_end=10118
  _globals['_GETEXTCALRECOMMENDEDINTERVALRESPONSE']._serialized_start=10120
  _globals['_GETEXTCALRECOMMENDEDINTERVALRESPONSE']._serialized_end=10190
  _globals['_GETEXTCALLASTDATEANDTIMEREQUEST']._serialized_start=10192
  _globals['_GETEXTCALLASTDATEANDTIMEREQUEST']._serialized_end=10261
  _globals['_GETEXTCALLASTDATEANDTIMERESPONSE']._serialized_start=10263
  _globals['_GETEXTCALLASTDATEANDTIMERESPONSE']._serialized_end=10385
  _globals['_READCURRENTTEMPERATUREREQUEST']._serialized_start=10387
  _globals['_READCURRENTTEMPERATUREREQUEST']._serialized_end=10454
  _globals['_READCURRENTTEMPERATURERESPONSE']._serialized_start=10456
  _globals['_READCURRENTTEMPERATURERESPONSE']._serialized_end=10525
  _globals['_GETEXTCALLASTTEMPREQUEST']._serialized_start=10527
  _globals['_GETEXTCALLASTTEMPREQUEST']._serialized_end=10589
  _globals['_GETEXTCALLASTTEMPRESPONSE']._serialized_start=10591
  _globals['_GETEXTCALLASTTEMPRESPONSE']._serialized_end=10655
  _globals['_GETSELFCALLASTDATEANDTIMEREQUEST']._serialized_start=10657
  _globals['_GETSELFCALLASTDATEANDTIMEREQUEST']._serialized_end=10727
  _globals['_GETSELFCALLASTDATEANDTIMERESPONSE']._serialized_start=10729
  _globals['_GETSELFCALLASTDATEANDTIMERESPONSE']._serialized_end=10852
  _globals['_GETSELFCALLASTTEMPREQUEST']._serialized_start=10854
  _globals['_GETSELFCALLASTTEMPREQUEST']._serialized_end=10917
  _globals['_GETSELFCALLASTTEMPRESPONSE']._serialized_start=10919
  _globals['_GETSELFCALLASTTEMPRESPONSE']._serialized_end=10984
  _globals['_GETLCRCOMPENSATIONLASTDATEANDTIMEREQUEST']._serialized_start=10987
  _globals['_GETLCRCOMPENSATIONLASTDATEANDTIMEREQUEST']._serialized_end=11212
  _globals['_GETLCRCOMPENSATIONLASTDATEANDTIMERESPONSE']._serialized_start=11215
  _globals['_GETLCRCOMPENSATIONLASTDATEANDTIMERESPONSE']._serialized_end=11346
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST']._serialized_start=11349
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST']._serialized_end=11528
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE']._serialized_start=11530
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE']._serialized_end=11588
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST']._serialized_start=11590
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST']._serialized_end=11668
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE']._serialized_start=11670
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE']._serialized_end=11729
  _globals['_DISABLESTARTTRIGGERREQUEST']._serialized_start=11731
  _globals['_DISABLESTARTTRIGGERREQUEST']._serialized_end=11795
  _globals['_DISABLESTARTTRIGGERRESPONSE']._serialized_start=11797
  _globals['_DISABLESTARTTRIGGERRESPONSE']._serialized_end=11842
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERREQUEST']._serialized_start=11845
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERREQUEST']._serialized_end=12034
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERRESPONSE']._serialized_start=12036
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERRESPONSE']._serialized_end=12104
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERREQUEST']._serialized_start=12106
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERREQUEST']._serialized_end=12194
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERRESPONSE']._serialized_start=12196
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERRESPONSE']._serialized_end=12265
  _globals['_DISABLESEQUENCEADVANCETRIGGERREQUEST']._serialized_start=12267
  _globals['_DISABLESEQUENCEADVANCETRIGGERREQUEST']._serialized_end=12341
  _globals['_DISABLESEQUENCEADVANCETRIGGERRESPONSE']._serialized_start=12343
  _globals['_DISABLESEQUENCEADVANCETRIGGERRESPONSE']._serialized_end=12398
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERREQUEST']._serialized_start=12401
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERREQUEST']._serialized_end=12581
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERRESPONSE']._serialized_start=12583
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERRESPONSE']._serialized_end=12642
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERREQUEST']._serialized_start=12644
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERREQUEST']._serialized_end=12723
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERRESPONSE']._serialized_start=12725
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERRESPONSE']._serialized_end=12785
  _globals['_DISABLESOURCETRIGGERREQUEST']._serialized_start=12787
  _globals['_DISABLESOURCETRIGGERREQUEST']._serialized_end=12852
  _globals['_DISABLESOURCETRIGGERRESPONSE']._serialized_start=12854
  _globals['_DISABLESOURCETRIGGERRESPONSE']._serialized_end=12900
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERREQUEST']._serialized_start=12903
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERREQUEST']._serialized_end=13084
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERRESPONSE']._serialized_start=13086
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERRESPONSE']._serialized_end=13146
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERREQUEST']._serialized_start=13148
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERREQUEST']._serialized_end=13228
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERRESPONSE']._serialized_start=13230
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERRESPONSE']._serialized_end=13291
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERREQUEST']._serialized_start=13294
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERREQUEST']._serialized_end=13473
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERRESPONSE']._serialized_start=13475
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERRESPONSE']._serialized_end=13533
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERREQUEST']._serialized_start=13535
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERREQUEST']._serialized_end=13613
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERRESPONSE']._serialized_start=13615
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERRESPONSE']._serialized_end=13674
  _globals['_DISABLEPULSETRIGGERREQUEST']._serialized_start=13676
  _globals['_DISABLEPULSETRIGGERREQUEST']._serialized_end=13740
  _globals['_DISABLEPULSETRIGGERRESPONSE']._serialized_start=13742
  _globals['_DISABLEPULSETRIGGERRESPONSE']._serialized_end=13787
  _globals['_EXPORTSIGNALREQUEST']._serialized_start=13790
  _globals['_EXPORTSIGNALREQUEST']._serialized_end=13984
  _globals['_EXPORTSIGNALRESPONSE']._serialized_start=13986
  _globals['_EXPORTSIGNALRESPONSE']._serialized_end=14024
  _globals['_SENDSOFTWAREEDGETRIGGERREQUEST']._serialized_start=14027
  _globals['_SENDSOFTWAREEDGETRIGGERREQUEST']._serialized_end=14198
  _globals['_SENDSOFTWAREEDGETRIGGERRESPONSE']._serialized_start=14200
  _globals['_SENDSOFTWAREEDGETRIGGERRESPONSE']._serialized_end=14249
  _globals['_WAITFOREVENTREQUEST']._serialized_start=14252
  _globals['_WAITFOREVENTREQUEST']._serialized_end=14410
  _globals['_WAITFOREVENTRESPONSE']._serialized_start=14412
  _globals['_WAITFOREVENTRESPONSE']._serialized_end=14450
  _globals['_DISABLEREQUEST']._serialized_start=14452
  _globals['_DISABLEREQUEST']._serialized_end=14504
  _globals['_DISABLERESPONSE']._serialized_start=14506
  _globals['_DISABLERESPONSE']._serialized_end=14539
  _globals['_RESETREQUEST']._serialized_start=14541
  _globals['_RESETREQUEST']._serialized_end=14591
  _globals['_RESETRESPONSE']._serialized_start=14593
  _globals['_RESETRESPONSE']._serialized_end=14624
  _globals['_RESETDEVICEREQUEST']._serialized_start=14626
  _globals['_RESETDEVICEREQUEST']._serialized_end=14682
  _globals['_RESETDEVICERESPONSE']._serialized_start=14684
  _globals['_RESETDEVICERESPONSE']._serialized_end=14721
  _globals['_SELFTESTREQUEST']._serialized_start=14723
  _globals['_SELFTESTREQUEST']._serialized_end=14776
  _globals['_SELFTESTRESPONSE']._serialized_start=14778
  _globals['_SELFTESTRESPONSE']._serialized_end=14865
  _globals['_REVISIONQUERYREQUEST']._serialized_start=14867
  _globals['_REVISIONQUERYREQUEST']._serialized_end=14925
  _globals['_REVISIONQUERYRESPONSE']._serialized_start=14927
  _globals['_REVISIONQUERYRESPONSE']._serialized_end=15029
  _globals['_RESETWITHDEFAULTSREQUEST']._serialized_start=15031
  _globals['_RESETWITHDEFAULTSREQUEST']._serialized_end=15093
  _globals['_RESETWITHDEFAULTSRESPONSE']._serialized_start=15095
  _globals['_RESETWITHDEFAULTSRESPONSE']._serialized_end=15138
  _globals['_GETCHANNELNAMEREQUEST']._serialized_start=15140
  _globals['_GETCHANNELNAMEREQUEST']._serialized_end=15214
  _globals['_GETCHANNELNAMERESPONSE']._serialized_start=15216
  _globals['_GETCHANNELNAMERESPONSE']._serialized_end=15278
  _globals['_GETCHANNELNAMEFROMSTRINGREQUEST']._serialized_start=15280
  _globals['_GETCHANNELNAMEFROMSTRINGREQUEST']._serialized_end=15364
  _globals['_GETCHANNELNAMEFROMSTRINGRESPONSE']._serialized_start=15366
  _globals['_GETCHANNELNAMEFROMSTRINGRESPONSE']._serialized_end=15438
  _globals['_GETNEXTCOERCIONRECORDREQUEST']._serialized_start=15440
  _globals['_GETNEXTCOERCIONRECORDREQUEST']._serialized_end=15506
  _globals['_GETNEXTCOERCIONRECORDRESPONSE']._serialized_start=15508
  _globals['_GETNEXTCOERCIONRECORDRESPONSE']._serialized_end=15580
  _globals['_CLEARINTERCHANGEWARNINGSREQUEST']._serialized_start=15582
  _globals['_CLEARINTERCHANGEWARNINGSREQUEST']._serialized_end=15651
  _globals['_CLEARINTERCHANGEWARNINGSRESPONSE']._serialized_start=15653
  _globals['_CLEARINTERCHANGEWARNINGSRESPONSE']._serialized_end=15703
  _globals['_RESETINTERCHANGECHECKREQUEST']._serialized_start=15705
  _globals['_RESETINTERCHANGECHECKREQUEST']._serialized_end=15771
  _globals['_RESETINTERCHANGECHECKRESPONSE']._serialized_start=15773
  _globals['_RESETINTERCHANGECHECKRESPONSE']._serialized_end=15820
  _globals['_GETNEXTINTERCHANGEWARNINGREQUEST']._serialized_start=15822
  _globals['_GETNEXTINTERCHANGEWARNINGREQUEST']._serialized_end=15892
  _globals['_GETNEXTINTERCHANGEWARNINGRESPONSE']._serialized_start=15894
  _globals['_GETNEXTINTERCHANGEWARNINGRESPONSE']._serialized_end=15974
  _globals['_GETERRORREQUEST']._serialized_start=15976
  _globals['_GETERRORREQUEST']._serialized_end=16029
  _globals['_GETERRORRESPONSE']._serialized_start=16031
  _globals['_GETERRORRESPONSE']._serialized_end=16100
  _globals['_CLEARERRORREQUEST']._serialized_start=16102
  _globals['_CLEARERRORREQUEST']._serialized_end=16157
  _globals['_CLEARERRORRESPONSE']._serialized_start=16159
  _globals['_CLEARERRORRESPONSE']._serialized_end=16195
  _globals['_ERRORMESSAGEREQUEST']._serialized_start=16197
  _globals['_ERRORMESSAGEREQUEST']._serialized_end=16274
  _globals['_ERRORMESSAGERESPONSE']._serialized_start=16276
  _globals['_ERRORMESSAGERESPONSE']._serialized_end=16337
  _globals['_SETATTRIBUTEVIINT32REQUEST']._serialized_start=16340
  _globals['_SETATTRIBUTEVIINT32REQUEST']._serialized_end=16613
  _globals['_SETATTRIBUTEVIINT32RESPONSE']._serialized_start=16615
  _globals['_SETATTRIBUTEVIINT32RESPONSE']._serialized_end=16660
  _globals['_SETATTRIBUTEVIINT64REQUEST']._serialized_start=16663
  _globals['_SETATTRIBUTEVIINT64REQUEST']._serialized_end=16836
  _globals['_SETATTRIBUTEVIINT64RESPONSE']._serialized_start=16838
  _globals['_SETATTRIBUTEVIINT64RESPONSE']._serialized_end=16883
  _globals['_SETATTRIBUTEVIREAL64REQUEST']._serialized_start=16886
  _globals['_SETATTRIBUTEVIREAL64REQUEST']._serialized_end=17161
  _globals['_SETATTRIBUTEVIREAL64RESPONSE']._serialized_start=17163
  _globals['_SETATTRIBUTEVIREAL64RESPONSE']._serialized_end=17209
  _globals['_SETATTRIBUTEVISTRINGREQUEST']._serialized_start=17212
  _globals['_SETATTRIBUTEVISTRINGREQUEST']._serialized_end=17386
  _globals['_SETATTRIBUTEVISTRINGRESPONSE']._serialized_start=17388
  _globals['_SETATTRIBUTEVISTRINGRESPONSE']._serialized_end=17434
  _globals['_SETATTRIBUTEVISESSIONREQUEST']._serialized_start=17437
  _globals['_SETATTRIBUTEVISESSIONREQUEST']._serialized_end=17632
  _globals['_SETATTRIBUTEVISESSIONRESPONSE']._serialized_start=17634
  _globals['_SETATTRIBUTEVISESSIONRESPONSE']._serialized_end=17681
  _globals['_SETATTRIBUTEVIBOOLEANREQUEST']._serialized_start=17684
  _globals['_SETATTRIBUTEVIBOOLEANREQUEST']._serialized_end=17855
  _globals['_SETATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=17857
  _globals['_SETATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=17904
  _globals['_GETATTRIBUTEVIINT32REQUEST']._serialized_start=17907
  _globals['_GETATTRIBUTEVIINT32REQUEST']._serialized_end=18051
  _globals['_GETATTRIBUTEVIINT32RESPONSE']._serialized_start=18053
  _globals['_GETATTRIBUTEVIINT32RESPONSE']._serialized_end=18123
  _globals['_GETATTRIBUTEVIINT64REQUEST']._serialized_start=18126
  _globals['_GETATTRIBUTEVIINT64REQUEST']._serialized_end=18270
  _globals['_GETATTRIBUTEVIINT64RESPONSE']._serialized_start=18272
  _globals['_GETATTRIBUTEVIINT64RESPONSE']._serialized_end=18342
  _globals['_GETATTRIBUTEVIREAL64REQUEST']._serialized_start=18345
  _globals['_GETATTRIBUTEVIREAL64REQUEST']._serialized_end=18490
  _globals['_GETATTRIBUTEVIREAL64RESPONSE']._serialized_start=18492
  _globals['_GETATTRIBUTEVIREAL64RESPONSE']._serialized_end=18563
  _globals['_GETATTRIBUTEVISTRINGREQUEST']._serialized_start=18566
  _globals['_GETATTRIBUTEVISTRINGREQUEST']._serialized_end=18711
  _globals['_GETATTRIBUTEVISTRINGRESPONSE']._serialized_start=18713
  _globals['_GETATTRIBUTEVISTRINGRESPONSE']._serialized_end=18784
  _globals['_GETATTRIBUTEVISESSIONREQUEST']._serialized_start=18787
  _globals['_GETATTRIBUTEVISESSIONREQUEST']._serialized_end=18933
  _globals['_GETATTRIBUTEVISESSIONRESPONSE']._serialized_start=18935
  _globals['_GETATTRIBUTEVISESSIONRESPONSE']._serialized_end=19031
  _globals['_GETATTRIBUTEVIBOOLEANREQUEST']._serialized_start=19034
  _globals['_GETATTRIBUTEVIBOOLEANREQUEST']._serialized_end=19180
  _globals['_GETATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=19182
  _globals['_GETATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=19254
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_start=19256
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_end=19352
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_start=19354
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_end=19412
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_start=19414
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_end=19510
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_start=19512
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_end=19570
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_start=19572
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_end=19674
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_start=19676
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_end=19736
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_start=19738
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_end=19817
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_start=19819
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_end=19902
  _globals['_PERFORMLCROPENCOMPENSATIONREQUEST']._serialized_start=19904
  _globals['_PERFORMLCROPENCOMPENSATIONREQUEST']._serialized_end=20029
  _globals['_PERFORMLCROPENCOMPENSATIONRESPONSE']._serialized_start=20031
  _globals['_PERFORMLCROPENCOMPENSATIONRESPONSE']._serialized_end=20083
  _globals['_PERFORMLCRSHORTCOMPENSATIONREQUEST']._serialized_start=20085
  _globals['_PERFORMLCRSHORTCOMPENSATIONREQUEST']._serialized_end=20211
  _globals['_PERFORMLCRSHORTCOMPENSATIONRESPONSE']._serialized_start=20213
  _globals['_PERFORMLCRSHORTCOMPENSATIONRESPONSE']._serialized_end=20266
  _globals['_PERFORMLCRLOADCOMPENSATIONREQUEST']._serialized_start=20269
  _globals['_PERFORMLCRLOADCOMPENSATIONREQUEST']._serialized_end=20433
  _globals['_PERFORMLCRLOADCOMPENSATIONRESPONSE']._serialized_start=20435
  _globals['_PERFORMLCRLOADCOMPENSATIONRESPONSE']._serialized_end=20487
  _globals['_CONFIGURELCRCOMPENSATIONREQUEST']._serialized_start=20489
  _globals['_CONFIGURELCRCOMPENSATIONREQUEST']._serialized_end=20607
  _globals['_CONFIGURELCRCOMPENSATIONRESPONSE']._serialized_start=20609
  _globals['_CONFIGURELCRCOMPENSATIONRESPONSE']._serialized_end=20659
  _globals['_PERFORMLCROPENCUSTOMCABLECOMPENSATIONREQUEST']._serialized_start=20661
  _globals['_PERFORMLCROPENCUSTOMCABLECOMPENSATIONREQUEST']._serialized_end=20765
  _globals['_PERFORMLCROPENCUSTOMCABLECOMPENSATIONRESPONSE']._serialized_start=20767
  _globals['_PERFORMLCROPENCUSTOMCABLECOMPENSATIONRESPONSE']._serialized_end=20830
  _globals['_PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONREQUEST']._serialized_start=20832
  _globals['_PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONREQUEST']._serialized_end=20937
  _globals['_PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONRESPONSE']._serialized_start=20939
  _globals['_PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONRESPONSE']._serialized_end=21003
  _globals['_GETLCRCOMPENSATIONDATAREQUEST']._serialized_start=21005
  _globals['_GETLCRCOMPENSATIONDATAREQUEST']._serialized_end=21094
  _globals['_GETLCRCOMPENSATIONDATARESPONSE']._serialized_start=21096
  _globals['_GETLCRCOMPENSATIONDATARESPONSE']._serialized_end=21171
  _globals['_INITIALIZEWITHINDEPENDENTCHANNELSREQUEST']._serialized_start=21174
  _globals['_INITIALIZEWITHINDEPENDENTCHANNELSREQUEST']._serialized_end=21378
  _globals['_INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE']._serialized_start=21381
  _globals['_INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE']._serialized_end=21536
  _globals['_CONFIGURESOURCEMODEWITHCHANNELSREQUEST']._serialized_start=21539
  _globals['_CONFIGURESOURCEMODEWITHCHANNELSREQUEST']._serialized_end=21735
  _globals['_CONFIGURESOURCEMODEWITHCHANNELSRESPONSE']._serialized_start=21737
  _globals['_CONFIGURESOURCEMODEWITHCHANNELSRESPONSE']._serialized_end=21794
  _globals['_CREATEADVANCEDSEQUENCEWITHCHANNELSREQUEST']._serialized_start=21797
  _globals['_CREATEADVANCEDSEQUENCEWITHCHANNELSREQUEST']._serialized_end=21976
  _globals['_CREATEADVANCEDSEQUENCEWITHCHANNELSRESPONSE']._serialized_start=21978
  _globals['_CREATEADVANCEDSEQUENCEWITHCHANNELSRESPONSE']._serialized_end=22038
  _globals['_CREATEADVANCEDSEQUENCESTEPWITHCHANNELSREQUEST']._serialized_start=22041
  _globals['_CREATEADVANCEDSEQUENCESTEPWITHCHANNELSREQUEST']._serialized_end=22174
  _globals['_CREATEADVANCEDSEQUENCESTEPWITHCHANNELSRESPONSE']._serialized_start=22176
  _globals['_CREATEADVANCEDSEQUENCESTEPWITHCHANNELSRESPONSE']._serialized_end=22240
  _globals['_CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSREQUEST']._serialized_start=22243
  _globals['_CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSREQUEST']._serialized_end=22382
  _globals['_CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSRESPONSE']._serialized_start=22384
  _globals['_CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSRESPONSE']._serialized_end=22454
  _globals['_DELETEADVANCEDSEQUENCEWITHCHANNELSREQUEST']._serialized_start=22456
  _globals['_DELETEADVANCEDSEQUENCEWITHCHANNELSREQUEST']._serialized_end=22580
  _globals['_DELETEADVANCEDSEQUENCEWITHCHANNELSRESPONSE']._serialized_start=22582
  _globals['_DELETEADVANCEDSEQUENCEWITHCHANNELSRESPONSE']._serialized_end=22642
  _globals['_COMMITWITHCHANNELSREQUEST']._serialized_start=22644
  _globals['_COMMITWITHCHANNELSREQUEST']._serialized_end=22729
  _globals['_COMMITWITHCHANNELSRESPONSE']._serialized_start=22731
  _globals['_COMMITWITHCHANNELSRESPONSE']._serialized_end=22775
  _globals['_INITIATEWITHCHANNELSREQUEST']._serialized_start=22777
  _globals['_INITIATEWITHCHANNELSREQUEST']._serialized_end=22864
  _globals['_INITIATEWITHCHANNELSRESPONSE']._serialized_start=22866
  _globals['_INITIATEWITHCHANNELSRESPONSE']._serialized_end=22912
  _globals['_ABORTWITHCHANNELSREQUEST']._serialized_start=22914
  _globals['_ABORTWITHCHANNELSREQUEST']._serialized_end=22998
  _globals['_ABORTWITHCHANNELSRESPONSE']._serialized_start=23000
  _globals['_ABORTWITHCHANNELSRESPONSE']._serialized_end=23043
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSREQUEST']._serialized_start=23046
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSREQUEST']._serialized_end=23259
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSRESPONSE']._serialized_start=23261
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSRESPONSE']._serialized_end=23331
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSREQUEST']._serialized_start=23333
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSREQUEST']._serialized_end=23445
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSRESPONSE']._serialized_start=23447
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSRESPONSE']._serialized_end=23518
  _globals['_DISABLESTARTTRIGGERWITHCHANNELSREQUEST']._serialized_start=23520
  _globals['_DISABLESTARTTRIGGERWITHCHANNELSREQUEST']._serialized_end=23618
  _globals['_DISABLESTARTTRIGGERWITHCHANNELSRESPONSE']._serialized_start=23620
  _globals['_DISABLESTARTTRIGGERWITHCHANNELSRESPONSE']._serialized_end=23677
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST']._serialized_start=23680
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST']._serialized_end=23903
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE']._serialized_start=23905
  _globals['_CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE']._serialized_end=23985
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST']._serialized_start=23987
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST']._serialized_end=24109
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE']._serialized_start=24111
  _globals['_CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE']._serialized_end=24192
  _globals['_DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST']._serialized_start=24194
  _globals['_DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST']._serialized_end=24302
  _globals['_DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE']._serialized_start=24304
  _globals['_DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE']._serialized_end=24371
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSREQUEST']._serialized_start=24374
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSREQUEST']._serialized_end=24588
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSRESPONSE']._serialized_start=24590
  _globals['_CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSRESPONSE']._serialized_end=24661
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSREQUEST']._serialized_start=24663
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSREQUEST']._serialized_end=24776
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSRESPONSE']._serialized_start=24778
  _globals['_CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSRESPONSE']._serialized_end=24850
  _globals['_DISABLESOURCETRIGGERWITHCHANNELSREQUEST']._serialized_start=24852
  _globals['_DISABLESOURCETRIGGERWITHCHANNELSREQUEST']._serialized_end=24951
  _globals['_DISABLESOURCETRIGGERWITHCHANNELSRESPONSE']._serialized_start=24953
  _globals['_DISABLESOURCETRIGGERWITHCHANNELSRESPONSE']._serialized_end=25011
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSREQUEST']._serialized_start=25014
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSREQUEST']._serialized_end=25229
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSRESPONSE']._serialized_start=25231
  _globals['_CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSRESPONSE']._serialized_end=25303
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSREQUEST']._serialized_start=25305
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSREQUEST']._serialized_end=25419
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSRESPONSE']._serialized_start=25421
  _globals['_CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSRESPONSE']._serialized_end=25494
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSREQUEST']._serialized_start=25497
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSREQUEST']._serialized_end=25710
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSRESPONSE']._serialized_start=25712
  _globals['_CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSRESPONSE']._serialized_end=25782
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSREQUEST']._serialized_start=25784
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSREQUEST']._serialized_end=25896
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSRESPONSE']._serialized_start=25898
  _globals['_CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSRESPONSE']._serialized_end=25969
  _globals['_DISABLEPULSETRIGGERWITHCHANNELSREQUEST']._serialized_start=25971
  _globals['_DISABLEPULSETRIGGERWITHCHANNELSREQUEST']._serialized_end=26069
  _globals['_DISABLEPULSETRIGGERWITHCHANNELSRESPONSE']._serialized_start=26071
  _globals['_DISABLEPULSETRIGGERWITHCHANNELSRESPONSE']._serialized_end=26128
  _globals['_CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST']._serialized_start=26131
  _globals['_CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST']._serialized_end=26347
  _globals['_CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE']._serialized_start=26349
  _globals['_CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE']._serialized_end=26422
  _globals['_CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST']._serialized_start=26424
  _globals['_CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST']._serialized_end=26539
  _globals['_CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE']._serialized_start=26541
  _globals['_CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE']._serialized_end=26615
  _globals['_DISABLESHUTDOWNTRIGGERWITHCHANNELSREQUEST']._serialized_start=26617
  _globals['_DISABLESHUTDOWNTRIGGERWITHCHANNELSREQUEST']._serialized_end=26718
  _globals['_DISABLESHUTDOWNTRIGGERWITHCHANNELSRESPONSE']._serialized_start=26720
  _globals['_DISABLESHUTDOWNTRIGGERWITHCHANNELSRESPONSE']._serialized_end=26780
  _globals['_EXPORTSIGNALWITHCHANNELSREQUEST']._serialized_start=26783
  _globals['_EXPORTSIGNALWITHCHANNELSREQUEST']._serialized_end=27011
  _globals['_EXPORTSIGNALWITHCHANNELSRESPONSE']._serialized_start=27013
  _globals['_EXPORTSIGNALWITHCHANNELSRESPONSE']._serialized_end=27063
  _globals['_SENDSOFTWAREEDGETRIGGERWITHCHANNELSREQUEST']._serialized_start=27066
  _globals['_SENDSOFTWAREEDGETRIGGERWITHCHANNELSREQUEST']._serialized_end=27271
  _globals['_SENDSOFTWAREEDGETRIGGERWITHCHANNELSRESPONSE']._serialized_start=27273
  _globals['_SENDSOFTWAREEDGETRIGGERWITHCHANNELSRESPONSE']._serialized_end=27334
  _globals['_WAITFOREVENTWITHCHANNELSREQUEST']._serialized_start=27337
  _globals['_WAITFOREVENTWITHCHANNELSREQUEST']._serialized_end=27529
  _globals['_WAITFOREVENTWITHCHANNELSRESPONSE']._serialized_start=27531
  _globals['_WAITFOREVENTWITHCHANNELSRESPONSE']._serialized_end=27581
  _globals['_RESETWITHCHANNELSREQUEST']._serialized_start=27583
  _globals['_RESETWITHCHANNELSREQUEST']._serialized_end=27667
  _globals['_RESETWITHCHANNELSRESPONSE']._serialized_start=27669
  _globals['_RESETWITHCHANNELSRESPONSE']._serialized_end=27712
  _globals['_INVALIDATEALLATTRIBUTESREQUEST']._serialized_start=27714
  _globals['_INVALIDATEALLATTRIBUTESREQUEST']._serialized_end=27782
  _globals['_INVALIDATEALLATTRIBUTESRESPONSE']._serialized_start=27784
  _globals['_INVALIDATEALLATTRIBUTESRESPONSE']._serialized_end=27833
  _globals['_CONFIGUREOVPREQUEST']._serialized_start=27835
  _globals['_CONFIGUREOVPREQUEST']._serialized_end=27946
  _globals['_CONFIGUREOVPRESPONSE']._serialized_start=27948
  _globals['_CONFIGUREOVPRESPONSE']._serialized_end=27986
  _globals['_ERRORQUERYREQUEST']._serialized_start=27988
  _globals['_ERRORQUERYREQUEST']._serialized_end=28043
  _globals['_ERRORQUERYRESPONSE']._serialized_start=28045
  _globals['_ERRORQUERYRESPONSE']._serialized_end=28124
  _globals['_GETLCRCUSTOMCABLECOMPENSATIONDATAREQUEST']._serialized_start=28126
  _globals['_GETLCRCUSTOMCABLECOMPENSATIONDATAREQUEST']._serialized_end=28226
  _globals['_GETLCRCUSTOMCABLECOMPENSATIONDATARESPONSE']._serialized_start=28228
  _globals['_GETLCRCUSTOMCABLECOMPENSATIONDATARESPONSE']._serialized_end=28327
  _globals['_CONFIGURELCRCUSTOMCABLECOMPENSATIONREQUEST']._serialized_start=28330
  _globals['_CONFIGURELCRCUSTOMCABLECOMPENSATIONREQUEST']._serialized_end=28472
  _globals['_CONFIGURELCRCUSTOMCABLECOMPENSATIONRESPONSE']._serialized_start=28474
  _globals['_CONFIGURELCRCUSTOMCABLECOMPENSATIONRESPONSE']._serialized_end=28535
  _globals['_NIDCPOWER']._serialized_start=52909
  _globals['_NIDCPOWER']._serialized_end=72260
# @@protoc_insertion_point(module_scope)
